(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     34347,       1201]*)
(*NotebookOutlinePosition[     35097,       1227]*)
(*  CellTagsIndexPosition[     35053,       1223]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.
Make modifications to any definition using commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellLabel->False,
  ImageSize->{200, 200},
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, None}, {
      None, None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageHeaderLines->{True, True},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellHorizontalScrolling->True,
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->{{0, 0}, {0, 0.25}},
  CellMargins->{{18, 30}, {4, 20}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameMargins->9,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{0.95, 11},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->36],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{18, 30}, {4, 0}},
  CellFrameMargins->4,
  FontSize->30]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{18, 30}, {0, 10}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 0},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->24,
  FontSlant->"Italic"],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{18, 30}, {0, 10}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellFrame->{{0, 0}, {0, 3}},
  CellMargins->{{18, 30}, {4, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->3,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Subsubtitle", "Printout"],
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{18, 30}, {4, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{18, 30}, {4, 20}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{18, 30}, {4, 12}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Subsubsection",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{18, 10}, {Inherited, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 2},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{55, 50}, {5, 5}},
  PageBreakAbove->False,
  Hyphenation->True,
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{55, 55}, {5, 2}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{55, 10}, {5, 10}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->False,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontFamily->"Courier",
  FontWeight->"Bold",
  GridBoxOptions->{GridFrame->False,
  RowLines->False,
  ColumnLines->False}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{55, 55}, {0, 10}},
  ShowCellLabel->False,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9.5]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{55, 10}, {8, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelPositioning->Left,
  CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{55, 55}, {10, 10}},
  ShowCellLabel->False,
  FontSize->9.5]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellDingbat->"\[LongDash]",
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{55, 55}, {0, 3}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Left,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{54, 72}, {2, 10}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  AspectRatioFixed->False,
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{55, 55}, {0, 15}},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  CellMargins->{{9, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontSlant->"Oblique"],

Cell[StyleData["CellLabel", "Printout"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unique Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{45, Inherited}, {2, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{36, Inherited}, {2, 30}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Address"],
  CellMargins->{{45, Inherited}, {2, 2}},
  CellGroupingRules->{"TitleGrouping", 30},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->12,
  FontSlant->"Italic"],

Cell[StyleData["Address", "Printout"],
  CellMargins->{{36, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Abstract"],
  CellMargins->{{45, 75}, {Inherited, 30}},
  Hyphenation->True,
  LineSpacing->{1, 0}],

Cell[StyleData["Abstract", "Printout"],
  CellMargins->{{36, 67}, {Inherited, 50}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{18, 40}, {2, 2}},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 0}],

Cell[StyleData["Reference", "Printout"],
  CellMargins->{{18, 40}, {Inherited, 0}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{55, 10}, {0, 10}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{55, 55}, {0, 10}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{55, 145}, {2, 10}},
  CellHorizontalScrolling->True,
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedFigure", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{55, 145}, {2, 10}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedTable", "Printout"],
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{55, 10}, {2, 10}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ChemicalFormula"],
  CellMargins->{{55, 10}, {2, 10}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  AutoSpacing->False,
  ScriptLevel->1,
  ScriptBaselineShifts->{0.6, Automatic},
  SingleLetterItalics->False,
  ZeroWidthTimes->True],

Cell[StyleData["ChemicalFormula", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellMargins->{{18, 10}, {Inherited, 6}},
  Hyphenation->False,
  LanguageCategory->"Formula",
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CalculationCenter Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathForm"],
  CellMargins->{{45, 10}, {5, 7}},
  Active->True,
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->False,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  GridBoxOptions->{GridFrame->False,
  RowLines->False,
  ColumnLines->False}],

Cell[StyleData["MathForm", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  Active->True,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontFamily->"Times New Roman",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathFormOutput"],
  CellMargins->{{47, 10}, {7, 5}},
  Active->True,
  CellEditDuplicate->True,
  Evaluatable->False,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None,
  FontFamily->"Times New Roman"],

Cell[StyleData["MathFormOutput", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  Active->True,
  FontFamily->"Times New Roman",
  FontSize->9]
}, Closed]],

Cell[StyleData["SCComment"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->GrayLevel[0]],

Cell[StyleData["ReverseSCComment"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["SCHelperGridLabels"],
  Editable->False,
  Selectable->False,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["HelperLabelEmphasised"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["HelperBackground"],
  StyleMenuListing->None,
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["ReverseHelperBackground"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["SCHelperGrid"],
  StyleMenuListing->None,
  Background->GrayLevel[1],
  GridBoxOptions->{ColumnAlignments->{Right, Left},
  GridFrame->True,
  RowLines->False,
  ColumnLines->True}],

Cell[StyleData["ExampleButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{
  ButtonFunction:>CalculationCenter`Functions`private`GiveExample[ ],
  ButtonEvaluator->Automatic,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Change parameters to pre-set example"}],

Cell[StyleData["ConvertCellButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        FrontEnd`EvaluationNotebook[ ], All, Cell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "SelectionConvert", "StandardForm"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Remove helper grid"}],

Cell[StyleData["CalculateCellButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "EvaluateCells"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["SCComment2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.400015, 0.600015, 0.400015]],

Cell[StyleData["ReverseSCComment2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.800015, 0.800015, 1],
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["SCHelperGridLabels2"],
  Editable->False,
  Selectable->False,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["HelperLabelEmphasised2"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["HelperBackground2"],
  StyleMenuListing->None,
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["ReverseHelperBackground2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontColor->RGBColor[0.800015, 0.800015, 1],
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["SCHelperGrid2"],
  StyleMenuListing->None,
  Background->GrayLevel[1],
  GridBoxOptions->{ColumnAlignments->{Right, Left},
  GridFrame->True,
  RowLines->False,
  ColumnLines->True}],

Cell[StyleData["ExampleButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{
  ButtonFunction:>CalculationCenter`Functions`private`GiveExample[ ],
  ButtonEvaluator->Automatic,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Change parameters to pre-set example"}],

Cell[StyleData["ConvertCellButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        FrontEnd`EvaluationNotebook[ ], All, Cell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "SelectionConvert", "StandardForm"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Remove helper grid"}],

Cell[StyleData["CalculateCellButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "EvaluateCells"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["OffForever"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonMargins->2,
  ButtonFrame->"Palette",
  Background->RGBColor[0.400015, 0.600015, 0.400015],
  ButtonNote->None}],

Cell[StyleData["MessageLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0.200015, 0.400015, 0.400015],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["PlotCellButtons"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["PlotTitle"],
  Editable->False,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.400015, 0.600015, 0.400015]],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->False,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["UnmatchedBracket"],
  StyleMenuListing->None,
  FontSize->18,
  FontColor->RGBColor[0.760006, 0.330007, 0.8]],

Cell[CellGroupData[{

Cell[StyleData["TraditionalUnitStyle"],
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["TraditionalUnitStyle", "Printout"],
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->GrayLevel[1]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1106}, {0, 848}},
WindowSize->{650, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingOptions->{"FirstPageHeader"->False,
"FirstPageFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 65, "Subtitle"],
Cell[1816, 55, 190, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2031, 63, 42, 0, 56, "Section"],
Cell[2076, 65, 51, 1, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2130, 68, 153, 4, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2320, 77, 35, 0, 36, "Section"],
Cell[2358, 79, 99, 2, 33, "Text"],
Cell[2460, 83, 457, 13, 40, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2954, 101, 38, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[3017, 105, 1043, 24, 91, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4063, 131, 110, 3, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4210, 139, 1012, 23, 48, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5225, 164, 91, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5353, 171, 1039, 24, 51, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[6395, 197, 58, 1, 74, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6490, 203, 981, 22, 45, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[7474, 227, 54, 1, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7565, 233, 1002, 23, 42, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[8570, 258, 57, 1, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8664, 264, 967, 22, 40, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[9634, 288, 60, 1, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9743, 295, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[9807, 299, 876, 20, 42, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[10686, 321, 117, 3, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10840, 329, 149, 5, 38, 26, 0, "StyleData", "Caption", "All",
  StyleMenuListing->None],
Cell[10992, 336, 88, 2, 70, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11129, 344, 42, 0, 36, "Section"],
Cell[11174, 346, 246, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[11445, 354, 741, 21, 44, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[12189, 377, 158, 4, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12384, 386, 631, 17, 42, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[13018, 405, 115, 3, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13170, 413, 605, 17, 35, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[13778, 432, 88, 2, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13903, 439, 588, 16, 38, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[14494, 457, 87, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14618, 464, 416, 12, 38, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[15037, 478, 141, 3, 42, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15215, 486, 177, 5, 37, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[15395, 493, 112, 2, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15556, 501, 32, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[15613, 505, 247, 6, 56, 25, 0, "StyleData", "Author", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[15863, 513, 96, 2, 70, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15996, 520, 271, 7, 38, 26, 0, "StyleData", "Address", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[16270, 529, 96, 2, 70, 38, 0, "StyleData", "Address", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16403, 536, 115, 3, 40, 27, 0, "StyleData", "Abstract", "All"],
Cell[16521, 541, 99, 2, 70, 39, 0, "StyleData", "Abstract", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16657, 548, 131, 4, 38, 28, 0, "StyleData", "Reference", "All"],
Cell[16791, 554, 98, 2, 70, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16938, 562, 35, 0, 36, "Section"],
Cell[16976, 564, 184, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[17185, 572, 302, 8, 40, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17490, 582, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[17628, 588, 104, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[17757, 595, 223, 6, 40, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[17983, 603, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18146, 611, 221, 6, 40, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[18370, 619, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18531, 627, 341, 9, 40, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18875, 638, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19038, 646, 328, 8, 40, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19369, 656, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19538, 664, 332, 8, 40, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19873, 674, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20056, 683, 33, 0, 36, "Section"],
Cell[20092, 685, 121, 3, 33, "Text"],
Cell[20216, 690, 216, 6, 40, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[20435, 698, 219, 6, 40, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[20657, 706, 223, 6, 40, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[20883, 714, 223, 6, 40, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[21109, 722, 227, 6, 40, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[21373, 733, 49, 0, 36, "Section"],
Cell[21425, 735, 225, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[21675, 743, 386, 8, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[22064, 753, 99, 2, 70, 47, 0, "StyleData", "NumberedEquation", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22200, 760, 325, 7, 70, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[22528, 769, 61, 1, 70, 45, 0, "StyleData", "NumberedFigure", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22626, 775, 313, 7, 70, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[22942, 784, 118, 2, 70, 44, 0, "StyleData", "NumberedTable", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23109, 792, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[23177, 796, 348, 8, 70, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[23528, 806, 61, 1, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23626, 812, 349, 9, 70, 34, 0, "StyleData", "ChemicalFormula", "All"],
Cell[23978, 823, 62, 1, 70, 46, 0, "StyleData", "ChemicalFormula", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24077, 829, 147, 4, 70, 26, 0, "StyleData", "Program", "All"],
Cell[24227, 835, 98, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24374, 843, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[24442, 847, 675, 21, 44, 27, 0, "StyleData", "MathForm", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[25120, 870, 182, 5, 70, 39, 0, "StyleData", "MathForm", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25339, 880, 563, 17, 43, 33, 0, "StyleData", "MathFormOutput", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[25905, 899, 143, 4, 70, 45, 0, "StyleData", "MathFormOutput", \
"Printout"]
}, Closed]],
Cell[26063, 906, 270, 10, 60, 28, 0, "StyleData", "SCComment", "All",
  StyleMenuListing->None],
Cell[26336, 918, 304, 10, 62, 35, 0, "StyleData", "ReverseSCComment", "All",
  StyleMenuListing->None],
Cell[26643, 930, 172, 6, 40, 37, 0, "StyleData", "SCHelperGridLabels", "All",
  StyleMenuListing->None],
Cell[26818, 938, 88, 2, 40, 40, 0, "StyleData", "HelperLabelEmphasised", \
"All",
  StyleMenuListing->None],
Cell[26909, 942, 114, 2, 56, 35, 0, "StyleData", "HelperBackground", "All",
  StyleMenuListing->None],
Cell[27026, 946, 298, 9, 56, 42, 0, "StyleData", "ReverseHelperBackground", \
"All",
  StyleMenuListing->None],
Cell[27327, 957, 197, 6, 56, 31, 0, "StyleData", "SCHelperGrid", "All",
  StyleMenuListing->None],
Cell[27527, 965, 402, 11, 70, 32, 0, "StyleData", "ExampleButton", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[27932, 978, 613, 16, 70, 36, 0, "StyleData", "ConvertCellButton", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[28548, 996, 575, 15, 70, 38, 0, "StyleData", "CalculateCellButton", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[29126, 1013, 285, 10, 70, 29, 0, "StyleData", "SCComment2", "All",
  StyleMenuListing->None],
Cell[29414, 1025, 313, 10, 70, 36, 0, "StyleData", "ReverseSCComment2", "All",
  
  StyleMenuListing->None],
Cell[29730, 1037, 173, 6, 70, 38, 0, "StyleData", "SCHelperGridLabels2", \
"All",
  StyleMenuListing->None],
Cell[29906, 1045, 89, 2, 70, 41, 0, "StyleData", "HelperLabelEmphasised2", \
"All",
  StyleMenuListing->None],
Cell[29998, 1049, 116, 2, 70, 36, 0, "StyleData", "HelperBackground2", "All",
  StyleMenuListing->None],
Cell[30117, 1053, 307, 9, 70, 43, 0, "StyleData", "ReverseHelperBackground2", \
"All",
  StyleMenuListing->None],
Cell[30427, 1064, 198, 6, 56, 32, 0, "StyleData", "SCHelperGrid2", "All",
  StyleMenuListing->None],
Cell[30628, 1072, 404, 11, 38, 33, 0, "StyleData", "ExampleButton2", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[31035, 1085, 615, 16, 38, 37, 0, "StyleData", "ConvertCellButton2", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[31653, 1103, 577, 15, 38, 39, 0, "StyleData", "CalculateCellButton2", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32233, 1120, 316, 10, 40, 29, 0, "StyleData", "OffForever", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32552, 1132, 393, 11, 40, 30, 0, "StyleData", "MessageLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32948, 1145, 347, 9, 38, 34, 0, "StyleData", "PlotCellButtons", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[33298, 1156, 287, 10, 62, 28, 0, "StyleData", "PlotTitle", "All",
  StyleMenuListing->None],
Cell[33588, 1168, 108, 3, 40, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[33699, 1173, 205, 6, 40, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[33907, 1181, 125, 3, 45, 35, 0, "StyleData", "UnmatchedBracket", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[34057, 1188, 120, 3, 40, 39, 0, "StyleData", "TraditionalUnitStyle", \
"All",
  StyleMenuListing->None],
Cell[34180, 1193, 127, 3, 70, 51, 0, "StyleData", "TraditionalUnitStyle", \
"Printout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

