(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38611,       1340]*)
(*NotebookOutlinePosition[     39246,       1362]*)
(*  CellTagsIndexPosition[     39202,       1358]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.
Make modifications to any definition using commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellLabel->False,
  CellFrameLabelMargins->6,
  ImageSize->{200, 200},
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, None}, {
      None, None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageHeaderLines->{True, True},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellHorizontalScrolling->True,
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->5,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellMargins->{{18, 10}, {4, 20}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameMargins->9,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{0.95, 12},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{18, 4}, {0, 0}},
  CellFrameMargins->4,
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{18, 10}, {0, 10}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 0},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->24],

Cell[StyleData["Subtitle", "Printout"],
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{18, 10}, {0, 10}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 0},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"],
  FontSize->14,
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SectionFirst"],
  CellFrame->{{0, 0}, {0, 3}},
  CellMargins->{{18, 10}, {10, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->5,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["SectionFirst", "Printout"],
  CellMargins->{{18, 4}, {10, 30}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{18, 10}, {10, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{18, 4}, {10, 30}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{18, 50}, {10, 26}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{18, 50}, {6, 20}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{18, 10}, {Inherited, 4}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{18, 4}, {Inherited, 0}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{55, 55}, {5, 4}},
  PageBreakAbove->False,
  Hyphenation->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{55, 10}, {5, 10}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->False,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontFamily->"Courier",
  FontWeight->"Bold",
  GridBoxOptions->{GridFrame->False,
  RowLines->False,
  ColumnLines->False}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{55, 55}, {0, 10}},
  ShowCellLabel->False,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->10]
}, Closed]],

Cell[StyleData["InlineInput"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{55, 10}, {10, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{55, 55}, {10, 0}},
  ShowCellLabel->False,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputOnly"],
  CellFrame->1,
  CellMargins->{{55, 10}, {0, 10}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold",
  Background->GrayLevel[0.850004]],

Cell[StyleData["InputOnly", "Printout"],
  CellMargins->{{55, 55}, {0, 10}},
  ShowCellLabel->False,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellFrame->{{1, 1}, {0, 0}},
  CellDingbat->"\[LongDash]",
  CellMargins->{{55, 10}, {0, 0}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontSlant->"Oblique"],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{55, 55}, {0, 0}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{55, 26}, {1, 6}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Left,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None,
  Background->GrayLevel[0.700008]],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{54, 72}, {2, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{55, 10}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  AspectRatioFixed->False,
  ImageMargins->{{0, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{55, 55}, {0, 0}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontSlant->"Oblique"],

Cell[StyleData["CellLabel", "Printout"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unique Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{20, Inherited}, {2, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{36, Inherited}, {2, 30}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Address"],
  CellMargins->{{18, Inherited}, {2, 2}},
  CellGroupingRules->{"TitleGrouping", 30},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSlant->"Italic"],

Cell[StyleData["Address", "Printout"],
  CellMargins->{{36, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Abstract"],
  CellFrame->False,
  CellMargins->{{45, 75}, {Inherited, 30}},
  Hyphenation->True,
  LineSpacing->{1, 1}],

Cell[StyleData["Abstract", "Printout"],
  CellMargins->{{36, 67}, {Inherited, 50}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{18, 40}, {Inherited, 0}},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 0}],

Cell[StyleData["Reference", "Printout"],
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PictureGroup"],
  CellFrame->{{1, 1}, {0, 0}},
  CellMargins->{{55, Inherited}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  ShowCellLabel->False,
  CounterIncrements->"Graphics",
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  Background->GrayLevel[0.850004]],

Cell[StyleData["PictureGroup", "Printout"],
  CellMargins->{{55, Inherited}, {0, 0}},
  ImageSize->{0.0625, 0.0625}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{55, 10}, {2, 10}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}], FontFamily -> "Helvetica",
           FontSize -> 10, FontWeight -> "Bold"]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}], FontFamily -> "Helvetica",
           FontSize -> 8, FontWeight -> "Bold"]}, {None, None}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{55, 145}, {2, 10}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
          FontSize -> 10, FontWeight -> "Bold"], None}},
  TextAlignment->Left,
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedFigure", "Printout"],
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
          FontSize -> 8, FontWeight -> "Bold"], None}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{55, 145}, {2, 10}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
          FontSize -> 10, FontWeight -> "Bold"], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedTable", "Printout"],
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
          FontSize -> 8, FontWeight -> "Bold"], None}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{55, 10}, {2, 10}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ChemicalFormula"],
  CellMargins->{{55, 10}, {2, 10}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  AutoSpacing->False,
  ScriptLevel->1,
  ScriptBaselineShifts->{0.6, Automatic},
  SingleLetterItalics->False,
  ZeroWidthTimes->True],

Cell[StyleData["ChemicalFormula", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellMargins->{{18, 10}, {Inherited, 6}},
  Hyphenation->False,
  LanguageCategory->"Formula",
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["PageNumber"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold"],

Cell[StyleData["Footer"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell["CalculationCenter Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathForm"],
  CellMargins->{{45, 10}, {5, 7}},
  Active->True,
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->False,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  GridBoxOptions->{GridFrame->False,
  RowLines->False,
  ColumnLines->False}],

Cell[StyleData["MathForm", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  Active->True,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontFamily->"Times New Roman",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathFormOutput"],
  CellMargins->{{47, 10}, {7, 5}},
  Active->True,
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None,
  FontFamily->"Times New Roman"],

Cell[StyleData["MathFormOutput", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  Active->True,
  FontFamily->"Times New Roman",
  FontSize->9]
}, Closed]],

Cell[StyleData["SCComment"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->GrayLevel[0]],

Cell[StyleData["ReverseSCComment"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["SCHelperGridLabels"],
  Editable->False,
  Selectable->False,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["HelperLabelEmphasised"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["HelperBackground"],
  StyleMenuListing->None,
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["ReverseHelperBackground"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["SCHelperGrid"],
  StyleMenuListing->None,
  Background->GrayLevel[1],
  GridBoxOptions->{ColumnAlignments->{Right, Left},
  GridFrame->True,
  RowLines->False,
  ColumnLines->True}],

Cell[StyleData["ExampleButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{
  ButtonFunction:>CalculationCenter`Functions`private`GiveExample[ ],
  ButtonEvaluator->Automatic,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Change parameters to pre-set example"}],

Cell[StyleData["ConvertCellButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        FrontEnd`EvaluationNotebook[ ], All, Cell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "SelectionConvert", "StandardForm"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Remove helper grid"}],

Cell[StyleData["CalculateCellButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "EvaluateCells"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["SCComment2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.400015, 0.600015, 0.400015]],

Cell[StyleData["ReverseSCComment2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.800015, 0.800015, 1],
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["SCHelperGridLabels2"],
  Editable->False,
  Selectable->False,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["HelperLabelEmphasised2"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["HelperBackground2"],
  StyleMenuListing->None,
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["ReverseHelperBackground2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontColor->RGBColor[0.800015, 0.800015, 1],
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["SCHelperGrid2"],
  StyleMenuListing->None,
  Background->GrayLevel[1],
  GridBoxOptions->{ColumnAlignments->{Right, Left},
  GridFrame->True,
  RowLines->False,
  ColumnLines->True}],

Cell[StyleData["ExampleButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{
  ButtonFunction:>CalculationCenter`Functions`private`GiveExample[ ],
  ButtonEvaluator->Automatic,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Change parameters to pre-set example"}],

Cell[StyleData["ConvertCellButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        FrontEnd`EvaluationNotebook[ ], All, Cell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "SelectionConvert", "StandardForm"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Remove helper grid"}],

Cell[StyleData["CalculateCellButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "EvaluateCells"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["OffForever"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonMargins->2,
  ButtonFrame->"Palette",
  Background->RGBColor[0.400015, 0.600015, 0.400015],
  ButtonNote->None}],

Cell[StyleData["MessageLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0.200015, 0.400015, 0.400015],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["PlotCellButtons"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["PlotTitle"],
  Editable->False,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.400015, 0.600015, 0.400015]],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->False,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["UnmatchedBracket"],
  StyleMenuListing->None,
  FontSize->18,
  FontColor->RGBColor[0.760006, 0.330007, 0.8]],

Cell[CellGroupData[{

Cell[StyleData["TraditionalUnitStyle"],
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["TraditionalUnitStyle", "Printout"],
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->GrayLevel[1]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1106}, {0, 848}},
WindowSize->{650, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 65, "Subtitle"],
Cell[1816, 55, 190, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2031, 63, 42, 0, 56, "Section"],
Cell[2076, 65, 51, 1, 40, 31, 0, "StyleData", "All", "Working"],
Cell[2130, 68, 181, 5, 38, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2348, 78, 35, 0, 36, "Section"],
Cell[2386, 80, 99, 2, 33, "Text"],
Cell[2488, 84, 457, 13, 40, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2982, 102, 38, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[3045, 106, 1091, 26, 93, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4139, 134, 109, 3, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4285, 142, 1016, 23, 48, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5304, 167, 55, 1, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5396, 173, 1042, 24, 43, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[6441, 199, 81, 2, 43, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6559, 206, 1094, 26, 60, 31, 0, "StyleData", "SectionFirst", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[7656, 234, 95, 2, 70, 43, 0, "StyleData", "SectionFirst", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7788, 241, 1009, 23, 52, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[8800, 266, 90, 2, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8927, 273, 1030, 24, 47, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[9960, 299, 57, 1, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10054, 305, 994, 23, 42, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[11051, 330, 60, 1, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11160, 337, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[11224, 341, 876, 20, 40, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[12103, 363, 116, 3, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12256, 371, 175, 6, 38, 26, 0, "StyleData", "Caption", "All",
  StyleMenuListing->None],
Cell[12434, 379, 53, 1, 70, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12536, 386, 42, 0, 36, "Section"],
Cell[12581, 388, 246, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[12852, 396, 741, 21, 44, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[13596, 419, 157, 4, 37, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[13768, 426, 468, 14, 38, 30, 0, "StyleData", "InlineInput", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[14261, 444, 602, 16, 40, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[14866, 462, 113, 3, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15016, 470, 692, 20, 52, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[15711, 492, 161, 4, 70, 40, 0, "StyleData", "InputOnly", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15909, 501, 641, 19, 34, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[16553, 522, 88, 2, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16678, 529, 600, 17, 53, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[17281, 548, 87, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17405, 555, 443, 13, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[17851, 570, 74, 1, 32, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17962, 576, 120, 4, 37, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[18085, 582, 112, 2, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18246, 590, 32, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[18303, 594, 275, 7, 70, 25, 0, "StyleData", "Author", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[18581, 603, 96, 2, 70, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18714, 610, 282, 7, 70, 26, 0, "StyleData", "Address", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[18999, 619, 96, 2, 70, 38, 0, "StyleData", "Address", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19132, 626, 135, 4, 70, 27, 0, "StyleData", "Abstract", "All"],
Cell[19270, 632, 99, 2, 70, 39, 0, "StyleData", "Abstract", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19406, 639, 139, 4, 70, 28, 0, "StyleData", "Reference", "All"],
Cell[19548, 645, 55, 1, 70, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19640, 651, 373, 10, 70, 31, 0, "StyleData", "PictureGroup", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[20016, 663, 116, 2, 70, 43, 0, "StyleData", "PictureGroup", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20181, 671, 35, 0, 36, "Section"],
Cell[20219, 673, 184, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[20428, 681, 302, 8, 40, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[20733, 691, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[20871, 697, 104, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[21000, 704, 223, 6, 40, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[21226, 712, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21389, 720, 221, 6, 40, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[21613, 728, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21774, 736, 341, 9, 40, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[22118, 747, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22281, 755, 328, 8, 40, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[22612, 765, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22781, 773, 332, 8, 40, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23116, 783, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23299, 792, 33, 0, 36, "Section"],
Cell[23335, 794, 121, 3, 33, "Text"],
Cell[23459, 799, 216, 6, 40, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[23678, 807, 219, 6, 40, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[23900, 815, 223, 6, 40, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[24126, 823, 223, 6, 40, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[24352, 831, 227, 6, 40, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[24616, 842, 49, 0, 36, "Section"],
Cell[24668, 844, 225, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[24918, 852, 462, 9, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[25383, 863, 252, 4, 70, 47, 0, "StyleData", "NumberedEquation", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25672, 872, 369, 8, 70, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[26044, 882, 249, 4, 70, 45, 0, "StyleData", "NumberedFigure", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26330, 891, 367, 8, 70, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[26700, 901, 246, 4, 70, 44, 0, "StyleData", "NumberedTable", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26995, 911, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[27063, 915, 348, 8, 70, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[27414, 925, 61, 1, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27512, 931, 349, 9, 70, 34, 0, "StyleData", "ChemicalFormula", "All"],
Cell[27864, 942, 62, 1, 70, 46, 0, "StyleData", "ChemicalFormula", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27963, 948, 147, 4, 70, 26, 0, "StyleData", "Program", "All"],
Cell[28113, 954, 98, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28260, 962, 49, 0, 36, "Section"],
Cell[28312, 964, 93, 3, 37, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[28408, 969, 119, 4, 36, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[28530, 975, 93, 3, 32, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[28660, 983, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[28728, 987, 675, 21, 44, 27, 0, "StyleData", "MathForm", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[29406, 1010, 182, 5, 70, 39, 0, "StyleData", "MathForm", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29625, 1020, 541, 16, 43, 33, 0, "StyleData", "MathFormOutput", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[30169, 1038, 143, 4, 70, 45, 0, "StyleData", "MathFormOutput", \
"Printout"]
}, Closed]],
Cell[30327, 1045, 270, 10, 60, 28, 0, "StyleData", "SCComment", "All",
  StyleMenuListing->None],
Cell[30600, 1057, 304, 10, 62, 35, 0, "StyleData", "ReverseSCComment", "All",
  StyleMenuListing->None],
Cell[30907, 1069, 172, 6, 40, 37, 0, "StyleData", "SCHelperGridLabels", "All",
  
  StyleMenuListing->None],
Cell[31082, 1077, 88, 2, 40, 40, 0, "StyleData", "HelperLabelEmphasised", \
"All",
  StyleMenuListing->None],
Cell[31173, 1081, 114, 2, 56, 35, 0, "StyleData", "HelperBackground", "All",
  StyleMenuListing->None],
Cell[31290, 1085, 298, 9, 56, 42, 0, "StyleData", "ReverseHelperBackground", \
"All",
  StyleMenuListing->None],
Cell[31591, 1096, 197, 6, 56, 31, 0, "StyleData", "SCHelperGrid", "All",
  StyleMenuListing->None],
Cell[31791, 1104, 402, 11, 70, 32, 0, "StyleData", "ExampleButton", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32196, 1117, 613, 16, 70, 36, 0, "StyleData", "ConvertCellButton", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32812, 1135, 575, 15, 70, 38, 0, "StyleData", "CalculateCellButton", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[33390, 1152, 285, 10, 70, 29, 0, "StyleData", "SCComment2", "All",
  StyleMenuListing->None],
Cell[33678, 1164, 313, 10, 70, 36, 0, "StyleData", "ReverseSCComment2", "All",
  
  StyleMenuListing->None],
Cell[33994, 1176, 173, 6, 70, 38, 0, "StyleData", "SCHelperGridLabels2", \
"All",
  StyleMenuListing->None],
Cell[34170, 1184, 89, 2, 70, 41, 0, "StyleData", "HelperLabelEmphasised2", \
"All",
  StyleMenuListing->None],
Cell[34262, 1188, 116, 2, 70, 36, 0, "StyleData", "HelperBackground2", "All",
  StyleMenuListing->None],
Cell[34381, 1192, 307, 9, 70, 43, 0, "StyleData", "ReverseHelperBackground2", \
"All",
  StyleMenuListing->None],
Cell[34691, 1203, 198, 6, 56, 32, 0, "StyleData", "SCHelperGrid2", "All",
  StyleMenuListing->None],
Cell[34892, 1211, 404, 11, 38, 33, 0, "StyleData", "ExampleButton2", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[35299, 1224, 615, 16, 38, 37, 0, "StyleData", "ConvertCellButton2", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[35917, 1242, 577, 15, 38, 39, 0, "StyleData", "CalculateCellButton2", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[36497, 1259, 316, 10, 40, 29, 0, "StyleData", "OffForever", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[36816, 1271, 393, 11, 40, 30, 0, "StyleData", "MessageLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[37212, 1284, 347, 9, 38, 34, 0, "StyleData", "PlotCellButtons", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[37562, 1295, 287, 10, 62, 28, 0, "StyleData", "PlotTitle", "All",
  StyleMenuListing->None],
Cell[37852, 1307, 108, 3, 40, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[37963, 1312, 205, 6, 40, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[38171, 1320, 125, 3, 45, 35, 0, "StyleData", "UnmatchedBracket", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[38321, 1327, 120, 3, 40, 39, 0, "StyleData", "TraditionalUnitStyle", \
"All",
  StyleMenuListing->None],
Cell[38444, 1332, 127, 3, 40, 51, 0, "StyleData", "TraditionalUnitStyle", \
"Printout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

