(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37803,       1318]*)
(*NotebookOutlinePosition[     38485,       1341]*)
(*  CellTagsIndexPosition[     38441,       1337]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->7,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, None}, {
      None, None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"FirstPageHeader"->False,
  "FirstPageFace"->Right},
  CellHorizontalScrolling->True,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.949996, 0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 13},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->34,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->24,
  Background->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 3},
  ParagraphIndent->-96,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0.700008, 0.700008]],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-85,
  FontSize->16,
  Background->GrayLevel[0.6]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {30, 10}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{9, 10}, {50, 10}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0, 1}},
  CellDingbat->None,
  CellMargins->{{12, Inherited}, {4, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 4}, {6, 2}},
  CellFrameLabelMargins->2,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{9, 0}, {2, 50}},
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellMargins->{{12, 10}, {25, 0}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  FontFamily->"Helvetica"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {4, 40}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellFrame->{{0, 0}, {0, 2}},
  CellMargins->{{12, 10}, {5, 20}},
  CellFrameMargins->{{0, 0}, {0, 2}},
  CellFrameColor->GrayLevel[1],
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  LineSpacing->{1, 0},
  ParagraphSpacing->{0, 12},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.4, 0, 0.6]],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{19, 0}, {4, 20}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {5, 5}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-.35999999999999999, -.10000000000000001}, \
{0, 0}}, BoxBaselineShift -> -.20000000000000001], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-.074999999999999997, -.085000000000000006}, \
{0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica"},
  Hyphenation->True,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  FontFamily->"Helvetica"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellMargins->{{52, 10}, {0, 10}},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 0}, {0, 2}},
  CellFrameColor->GrayLevel[1],
  Hyphenation->True,
  LineSpacing->{1, 0},
  ParagraphSpacing->{0, 12},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->{{4, 4}, {0, 4}},
  CellMargins->{{52, 10}, {0, 2}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->False,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  FontWeight->"Bold",
  Background->GrayLevel[1],
  GridBoxOptions->{GridFrame->False,
  RowLines->False,
  ColumnLines->False}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{37, 0}, {0, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1}]
}, Closed]],

Cell[StyleData["InlineInput"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->{{4, 4}, {4, 0}},
  CellMargins->{{52, 10}, {12, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  Background->GrayLevel[1]],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{37, 0}, {6, 0}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputOnly"],
  CellFrame->4,
  CellMargins->{{52, 10}, {4, 2}},
  Evaluatable->True,
  CellGroupingRules->"NormalGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  FontWeight->"Bold",
  Background->GrayLevel[1]],

Cell[StyleData["InputOnly", "Printout"],
  LinebreakAdjustments->{0.85, 2, 10, 1, 1}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OutputOnly"],
  CellFrame->4,
  CellMargins->{{52, 10}, {4, 2}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  Background->GrayLevel[1]],

Cell[StyleData["OutputOnly", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SymbolicExpression"],
  CellFrame->1,
  CellMargins->{{52, 10}, {4, 2}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->GrayLevel[0],
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["SymbolicExpression", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{52, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  StyleMenuListing->None,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{52, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Info"],
  CellMargins->{{52, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Info", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellFrame->{{4, 4}, {4, 0}},
  CellMargins->{{52, 10}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  AspectRatioFixed->False,
  ImageMargins->{{0, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  Background->GrayLevel[1]],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{37, 0}, {6, 0}},
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ImportPict"],
  CellMargins->{{52, 10}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->"ImportPict",
  Background->None],

Cell[StyleData["ImportPict", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.4, 0.4, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Unique Items", "Section"],

Cell[CellGroupData[{

Cell[StyleData["PullQuote"],
  CellFrame->{{0, 0}, {0, 3}},
  CellMargins->{{0, 250}, {15, 5}},
  CellFrameMargins->{{20, 4}, {8, 6}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 12},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.6, 0, 0.8]],

Cell[StyleData["PullQuote", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GrayBox"],
  CellFrame->{{0, 0}, {0, 3}},
  CellMargins->{{62, 36}, {10, 5}},
  CellFrameMargins->{{8, 4}, {8, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.8, 0.700008, 0.6]],

Cell[StyleData["GrayBox", "Printout"],
  CellMargins->{{62, 36}, {10, 5}},
  Background->GrayLevel[0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellFrame->4,
  CellMargins->{{52, 10}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  Background->GrayLevel[1]],

Cell[StyleData["Picture", "Printout"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PictureGroup"],
  CellFrame->{{4, 4}, {0, 0}},
  CellMargins->{{52, Inherited}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  ShowCellLabel->False,
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  Background->GrayLevel[1]],

Cell[StyleData["PictureGroup", "Printout"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}}]
}, Closed]],

Cell[StyleData["LineSpace"],
  CellMargins->{{0, 0}, {0, 0}},
  CellElementSpacings->{"CellMinHeight"->2},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  ButtonBoxOptions->{ButtonFunction:>Message[ 
      MessageName[ General, "incomp"]],
  ButtonEvaluator->Automatic,
  Active->True}]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->6],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  CellFrame->1,
  CellMargins->{{52, 10}, {4, 2}},
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell["CalculationCenter Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathForm"],
  CellFrame->{{4, 4}, {0, 4}},
  CellMargins->{{52, 10}, {0, 2}},
  Active->True,
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->False,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  GridBoxOptions->{GridFrame->False,
  RowLines->False,
  ColumnLines->False}],

Cell[StyleData["MathForm", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  Active->True,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontFamily->"Times New Roman",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathFormOutput"],
  CellFrame->{{4, 4}, {4, 0}},
  CellMargins->{{52, 10}, {12, 0}},
  Active->True,
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellFrameColor->RGBColor[0.8, 0.700008, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None,
  FontFamily->"Times New Roman"],

Cell[StyleData["MathFormOutput", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  Active->True,
  FontFamily->"Times New Roman",
  FontSize->9]
}, Closed]],

Cell[StyleData["SCComment"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->GrayLevel[0]],

Cell[StyleData["ReverseSCComment"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["SCHelperGridLabels"],
  Editable->False,
  Selectable->False,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["HelperLabelEmphasised"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["HelperBackground"],
  StyleMenuListing->None,
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["ReverseHelperBackground"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontColor->RGBColor[0.398444, 1, 1],
  Background->RGBColor[0.200015, 0.398444, 0.59765]],

Cell[StyleData["SCHelperGrid"],
  StyleMenuListing->None,
  Background->GrayLevel[1],
  GridBoxOptions->{ColumnAlignments->{Right, Left},
  GridFrame->True,
  RowLines->False,
  ColumnLines->True}],

Cell[StyleData["ExampleButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{
  ButtonFunction:>CalculationCenter`Functions`private`GiveExample[ ],
  ButtonEvaluator->Automatic,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Change parameters to pre-set example"}],

Cell[StyleData["ConvertCellButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        FrontEnd`EvaluationNotebook[ ], All, Cell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "SelectionConvert", "StandardForm"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Remove helper grid"}],

Cell[StyleData["CalculateCellButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "EvaluateCells"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.59765, 0.796872, 0.796872],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["SCComment2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.400015, 0.600015, 0.400015]],

Cell[StyleData["ReverseSCComment2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.800015, 0.800015, 1],
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["SCHelperGridLabels2"],
  Editable->False,
  Selectable->False,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["HelperLabelEmphasised2"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["HelperBackground2"],
  StyleMenuListing->None,
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["ReverseHelperBackground2"],
  Editable->True,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontColor->RGBColor[0.800015, 0.800015, 1],
  Background->RGBColor[0.200015, 0.300008, 0.500008]],

Cell[StyleData["SCHelperGrid2"],
  StyleMenuListing->None,
  Background->GrayLevel[1],
  GridBoxOptions->{ColumnAlignments->{Right, Left},
  GridFrame->True,
  RowLines->False,
  ColumnLines->True}],

Cell[StyleData["ExampleButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{
  ButtonFunction:>CalculationCenter`Functions`private`GiveExample[ ],
  ButtonEvaluator->Automatic,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Change parameters to pre-set example"}],

Cell[StyleData["ConvertCellButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        FrontEnd`EvaluationNotebook[ ], All, Cell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "SelectionConvert", "StandardForm"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Remove helper grid"}],

Cell[StyleData["CalculateCellButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`ButtonNotebook[ ], All, ButtonCell], 
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "EvaluateCells"]}],
  ButtonEvaluator->None,
  Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["OffForever"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonMargins->2,
  ButtonFrame->"Palette",
  Background->RGBColor[0.400015, 0.600015, 0.400015],
  ButtonNote->None}],

Cell[StyleData["MessageLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0.200015, 0.400015, 0.400015],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["PlotCellButtons"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  ButtonBoxOptions->{Active->True,
  Background->RGBColor[0.800015, 0.800015, 0.600015],
  ButtonNote->"Give the result of this computation"},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[StyleData["PlotTitle"],
  Editable->False,
  Deletable->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.400015, 0.600015, 0.400015]],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->False,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["UnmatchedBracket"],
  StyleMenuListing->None,
  FontSize->18,
  FontColor->RGBColor[0.760006, 0.330007, 0.8]],

Cell[CellGroupData[{

Cell[StyleData["TraditionalUnitStyle"],
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["TraditionalUnitStyle", "Printout"],
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->GrayLevel[1]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1106}, {0, 848}},
WindowSize->{650, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellMargins->{{0, Inherited}, {Inherited, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 65, "Subtitle"],
Cell[1816, 55, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2034, 63, 42, 0, 56, "Section"],
Cell[2079, 65, 77, 2, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2159, 69, 140, 4, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2336, 78, 35, 0, 36, "Section"],
Cell[2374, 80, 99, 2, 70, "Text"],
Cell[2476, 84, 416, 11, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2929, 100, 38, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[2992, 104, 1037, 25, 70, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4032, 131, 113, 3, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4182, 139, 1062, 25, 70, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5247, 166, 142, 4, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5426, 175, 968, 22, 70, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[6397, 199, 94, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6528, 206, 1160, 28, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[7691, 236, 140, 4, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7868, 245, 857, 19, 70, 29, 0, "StyleData", "Subsection", "All"],
Cell[8728, 266, 91, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8856, 273, 1058, 26, 70, 32, 0, "StyleData", "Subsubsection", "All"],
Cell[9917, 301, 95, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10061, 309, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[10125, 313, 871, 20, 70, 23, 0, "StyleData", "Text", "All"],
Cell[10999, 335, 112, 3, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11148, 343, 347, 12, 70, 29, 0, "StyleData", "Commentary", "All",
  StyleMenuListing->None],
Cell[11498, 357, 118, 3, 70, 41, 0, "StyleData", "Commentary", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11665, 366, 42, 0, 36, "Section"],
Cell[11710, 368, 246, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[11981, 376, 793, 22, 54, 24, 0, "StyleData", "Input", "All"],
Cell[12777, 400, 115, 2, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[12907, 405, 468, 14, 40, 30, 0, "StyleData", "InlineInput", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[13400, 423, 655, 17, 64, 25, 0, "StyleData", "Output", "All"],
Cell[14058, 442, 71, 1, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14166, 448, 654, 18, 64, 28, 0, "StyleData", "InputOnly", "All"],
Cell[14823, 468, 85, 1, 70, 40, 0, "StyleData", "InputOnly", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14945, 474, 594, 16, 64, 29, 0, "StyleData", "OutputOnly", "All"],
Cell[15542, 492, 41, 0, 70, 41, 0, "StyleData", "OutputOnly", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15620, 497, 729, 22, 58, 37, 0, "StyleData", "SymbolicExpression", \
"All"],
Cell[16352, 521, 49, 0, 70, 49, 0, "StyleData", "SymbolicExpression", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16438, 526, 513, 13, 40, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[16954, 541, 123, 2, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17114, 548, 512, 13, 40, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[17629, 563, 94, 1, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17760, 569, 511, 13, 40, 23, 0, "StyleData", "Info", "All",
  StyleMenuListing->None],
Cell[18274, 584, 93, 1, 70, 35, 0, "StyleData", "Info", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18404, 590, 517, 15, 56, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[18924, 607, 149, 3, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19110, 615, 312, 9, 36, 29, 0, "StyleData", "ImportPict", "All",
  StyleMenuListing->"ImportPict"],
Cell[19425, 626, 41, 0, 70, 41, 0, "StyleData", "ImportPict", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19503, 631, 179, 6, 38, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[19685, 639, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19864, 649, 42, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[19931, 653, 315, 10, 70, 28, 0, "StyleData", "PullQuote", "All"],
Cell[20249, 665, 117, 3, 70, 40, 0, "StyleData", "PullQuote", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20403, 673, 320, 10, 70, 26, 0, "StyleData", "GrayBox", "All"],
Cell[20726, 685, 104, 2, 70, 38, 0, "StyleData", "GrayBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20867, 692, 350, 10, 70, 26, 0, "StyleData", "Picture", "All",
  StyleMenuListing->None],
Cell[21220, 704, 114, 2, 70, 38, 0, "StyleData", "Picture", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21371, 711, 381, 10, 70, 31, 0, "StyleData", "PictureGroup", "All",
  StyleMenuListing->None],
Cell[21755, 723, 119, 2, 70, 43, 0, "StyleData", "PictureGroup", "Printout"]
}, Closed]],
Cell[21889, 728, 121, 3, 70, 28, 0, "StyleData", "LineSpace", "All"]
}, Closed]],

Cell[CellGroupData[{
Cell[22047, 736, 35, 0, 36, "Section"],
Cell[22085, 738, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[22294, 746, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[22599, 756, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[22737, 762, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[22866, 769, 223, 6, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[23092, 777, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23255, 785, 221, 6, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[23479, 793, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23640, 801, 341, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23984, 812, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24147, 820, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24478, 830, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24647, 838, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24982, 848, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25165, 857, 33, 0, 36, "Section"],
Cell[25201, 859, 121, 3, 70, "Text"],
Cell[25325, 864, 216, 6, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[25544, 872, 219, 6, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[25766, 880, 223, 6, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[25992, 888, 223, 6, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[26218, 896, 227, 6, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[26482, 907, 49, 0, 36, "Section"],
Cell[26534, 909, 149, 5, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[26686, 916, 126, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[26815, 922, 152, 5, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[27004, 932, 36, 0, 36, "Section"],
Cell[27043, 934, 258, 5, 70, "Text"],
Cell[27304, 941, 352, 11, 70, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[27693, 957, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[27761, 961, 754, 23, 46, 27, 0, "StyleData", "MathForm", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[28518, 986, 182, 5, 70, 39, 0, "StyleData", "MathForm", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28737, 996, 621, 18, 60, 33, 0, "StyleData", "MathFormOutput", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[29361, 1016, 143, 4, 70, 45, 0, "StyleData", "MathFormOutput", \
"Printout"]
}, Closed]],
Cell[29519, 1023, 270, 10, 60, 28, 0, "StyleData", "SCComment", "All",
  StyleMenuListing->None],
Cell[29792, 1035, 304, 10, 70, 35, 0, "StyleData", "ReverseSCComment", "All",
  StyleMenuListing->None],
Cell[30099, 1047, 172, 6, 70, 37, 0, "StyleData", "SCHelperGridLabels", "All",
  
  StyleMenuListing->None],
Cell[30274, 1055, 88, 2, 70, 40, 0, "StyleData", "HelperLabelEmphasised", \
"All",
  StyleMenuListing->None],
Cell[30365, 1059, 114, 2, 70, 35, 0, "StyleData", "HelperBackground", "All",
  StyleMenuListing->None],
Cell[30482, 1063, 298, 9, 70, 42, 0, "StyleData", "ReverseHelperBackground", \
"All",
  StyleMenuListing->None],
Cell[30783, 1074, 197, 6, 70, 31, 0, "StyleData", "SCHelperGrid", "All",
  StyleMenuListing->None],
Cell[30983, 1082, 402, 11, 70, 32, 0, "StyleData", "ExampleButton", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[31388, 1095, 613, 16, 70, 36, 0, "StyleData", "ConvertCellButton", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32004, 1113, 575, 15, 70, 38, 0, "StyleData", "CalculateCellButton", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[32582, 1130, 285, 10, 70, 29, 0, "StyleData", "SCComment2", "All",
  StyleMenuListing->None],
Cell[32870, 1142, 313, 10, 70, 36, 0, "StyleData", "ReverseSCComment2", "All",
  
  StyleMenuListing->None],
Cell[33186, 1154, 173, 6, 70, 38, 0, "StyleData", "SCHelperGridLabels2", \
"All",
  StyleMenuListing->None],
Cell[33362, 1162, 89, 2, 70, 41, 0, "StyleData", "HelperLabelEmphasised2", \
"All",
  StyleMenuListing->None],
Cell[33454, 1166, 116, 2, 70, 36, 0, "StyleData", "HelperBackground2", "All",
  StyleMenuListing->None],
Cell[33573, 1170, 307, 9, 70, 43, 0, "StyleData", "ReverseHelperBackground2", \
"All",
  StyleMenuListing->None],
Cell[33883, 1181, 198, 6, 70, 32, 0, "StyleData", "SCHelperGrid2", "All",
  StyleMenuListing->None],
Cell[34084, 1189, 404, 11, 70, 33, 0, "StyleData", "ExampleButton2", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[34491, 1202, 615, 16, 70, 37, 0, "StyleData", "ConvertCellButton2", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[35109, 1220, 577, 15, 70, 39, 0, "StyleData", "CalculateCellButton2", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[35689, 1237, 316, 10, 70, 29, 0, "StyleData", "OffForever", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[36008, 1249, 393, 11, 70, 30, 0, "StyleData", "MessageLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[36404, 1262, 347, 9, 70, 34, 0, "StyleData", "PlotCellButtons", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[36754, 1273, 287, 10, 70, 28, 0, "StyleData", "PlotTitle", "All",
  StyleMenuListing->None],
Cell[37044, 1285, 108, 3, 70, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[37155, 1290, 205, 6, 70, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[37363, 1298, 125, 3, 70, 35, 0, "StyleData", "UnmatchedBracket", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[37513, 1305, 120, 3, 70, 39, 0, "StyleData", "TraditionalUnitStyle", \
"All",
  StyleMenuListing->None],
Cell[37636, 1310, 127, 3, 70, 51, 0, "StyleData", "TraditionalUnitStyle", \
"Printout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

