(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43959,       1763]*)
(*NotebookOutlinePosition[     67882,       2628]*)
(*  CellTagsIndexPosition[     67838,       2624]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  ScriptSizeMultipliers->1,
  ScriptMinSize->9],

Cell[StyleData[All, "Brackets"],
  PageWidth->WindowWidth,
  ShowCellBracket->True,
  ScriptSizeMultipliers->1,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptSizeMultipliers->0.71,
  ScriptMinSize->7,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "Proof"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  ShowCellTags->True,
  ScriptSizeMultipliers->0.71,
  ScriptMinSize->7,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\

The options defined for the style below will be used at the 
Notebook level.
\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageFooters->{{None, Cell[ 
          TextData[ {"Printed by ", 
            StyleBox[ "Calculus WIZ", FontSlant -> "Italic"], 
            "\n\[Copyright] 2000 Wolfram Research, Inc.\n\
www.wolfram.com/wiz"}], "Footer"], None}, {None, Cell[ 
          TextData[ {"Printed by ", 
            StyleBox[ "Calculus WIZ", FontSlant -> "Italic"], 
            "\n\[Copyright] 2000 Wolfram Research, Inc.\n\
www.wolfram.com.com/wiz"}], "Footer"], None}},
  PageFooterLines->{True, True},
  PrintingOptions->{"FirstPageHeader"->False,
  "FirstPageFace"->Right},
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  LineSpacing->{1, 0},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->34,
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->24,
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[StyleData["Title", "Proof"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->24,
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 0}, {6, 6}},
  LineSpacing->{1, 3},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[1, 0.8, 0.2]],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-85,
  FontSize->16,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.6]],

Cell[StyleData["Subtitle", "Proof"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-85,
  FontSize->16,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.6]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 0}, {6, 6}},
  LineSpacing->{1, 3},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.4, 0, 0.4]],

Cell[StyleData["Subsubtitle", "Printout"],
  ParagraphIndent->-85,
  FontSize->16,
  FontColor->GrayLevel[1],
  Background->GrayLevel[0.6]],

Cell[StyleData["Subsubtitle", "Proof"],
  ParagraphIndent->-85,
  FontSize->16,
  FontColor->GrayLevel[1],
  Background->GrayLevel[0.6]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 0}, {10, 8}},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["Section", "Printout"],
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]],

Cell[StyleData["Section", "Proof"],
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{26, Inherited}, {4, 20}},
  CellElementSpacings->{"ClosedGroupTopMargin"->12},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->15,
  FontWeight->"Bold",
  FontColor->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["Subsection", "Printout"],
  FontSize->12,
  FontColor->GrayLevel[0]],

Cell[StyleData["Subsection", "Proof"],
  FontSize->12,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{12, Inherited}, {8, 16}},
  CellElementSpacings->{"ClosedGroupTopMargin"->1},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->15,
  FontWeight->"Bold",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["Subsubsection", "Printout"],
  ShowGroupOpenCloseIcon->False,
  FontSize->11,
  FontColor->GrayLevel[0]],

Cell[StyleData["Subsubsection", "Proof"],
  ShowGroupOpenCloseIcon->False,
  FontSize->11,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsectionIcon"],
  CellDingbat->None,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{12, 0}, {4, 20}},
  CellGroupingRules->{"SectionGrouping", 10},
  CellFrameMargins->12,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 0.4]],

Cell[StyleData["SubsectionIcon", "Printout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  LimitsPositioningTokens->{},
  FontFamily->"Times",
  FontSize->14],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{12, 10}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10],

Cell[StyleData["Text", "Proof"],
  CellMargins->{{12, 10}, {4, 4}},
  LineSpacing->{2, 0},
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 6},
  LimitsPositioningTokens->{},
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{12, 10}, {4, 4}},
  FontSize->7],

Cell[StyleData["SmallText", "Proof"],
  CellMargins->{{12, 10}, {4, 4}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\

The cells in this section define styles used for input and output 
to the kernel.  Be careful when modifying, renaming, or removing these 
styles, because the front end associates special meanings with these style 
names.
\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{52, 35}, {5, 5}},
  Evaluatable->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 1]],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{Inherited, Inherited}, {5, 5}},
  FontSize->10,
  Background->GrayLevel[0.700008]],

Cell[StyleData["Input", "Proof"],
  CellMargins->{{Inherited, Inherited}, {5, 5}},
  FontSize->10,
  Background->GrayLevel[0.700008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Input2"],
  CellMargins->{{52, 35}, {5, 5}},
  Evaluatable->True,
  CellGroupingRules->{"SectionGrouping", 55},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 1]],

Cell[StyleData["Input2", "Printout"],
  CellMargins->{{Inherited, Inherited}, {5, 5}},
  FontSize->10,
  Background->GrayLevel[0.700008]],

Cell[StyleData["Input2", "Proof"],
  CellMargins->{{Inherited, Inherited}, {5, 5}},
  FontSize->10,
  Background->GrayLevel[0.700008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{52, 35}, {8, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->{"SectionGrouping", 60},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["Output", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Output", "Proof"],
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{52, 26}, {8, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "Proof"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{52, 35}, {8, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["Print", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Print", "Proof"],
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{52, 35}, {8, 0}},
  CellGroupingRules->{"SectionGrouping", 60},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  ImageSize->{180, 180},
  StyleMenuListing->None,
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["Graphics", "Printout"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Graphics", "Proof"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GraphicsGroup"],
  CellMargins->{{52, 35}, {8, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  ImageSize->{180, 180},
  StyleMenuListing->None,
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["GraphicsGroup", "Printout"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["GraphicsGroup", "Proof"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["CellLabel", "Printout"],
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "Proof"],
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Miscellaneous Elements", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{10, 4}, {2, 10}},
  StyleMenuListing->None,
  FontSize->16,
  FontSlant->"Italic"],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{9, 0}, {4, 12}},
  ParagraphSpacing->{0, 6},
  FontSize->14],

Cell[StyleData["Author", "Proof"],
  CellMargins->{{9, 0}, {4, 12}},
  ParagraphSpacing->{0, 6},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Copyright"],
  CellMargins->{{10, 10}, {40, 2}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Copyright", "Printout"],
  CellMargins->{{9, 0}, {72, 4}},
  FontSize->7],

Cell[StyleData["Copyright", "Proof"],
  CellMargins->{{9, 0}, {72, 4}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["EndOfExercise"],
  CellMargins->{{52, 35}, {0, 0}},
  Evaluatable->False,
  CellGroupingRules->{"SectionGrouping", 55},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 1]],

Cell[StyleData["EndOfExercise", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.700008]],

Cell[StyleData["EndOfExercise", "Proof"],
  FontSize->10,
  Background->GrayLevel[0.700008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{50, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  LimitsPositioningTokens->{},
  FontFamily->"Times",
  FontSize->14],

Cell[StyleData["IndentedText", "Printout"],
  CellMargins->{{50, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10],

Cell[StyleData["IndentedText", "Proof"],
  CellMargins->{{50, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{50, 10}, {5, 5}},
  CellGroupingRules->{"SectionGrouping", 60},
  DefaultFormatType->DefaultInputFormatType,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  LimitsPositioningTokens->{},
  FontFamily->"Times",
  FontSize->14],

Cell[StyleData["DisplayFormula", "Printout"],
  ParagraphSpacing->{0, 6},
  FontSize->10],

Cell[StyleData["DisplayFormula", "Proof"],
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExampleSection"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{50, 10}, {5, 5}},
  CellGroupingRules->{"SectionGrouping", 60},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  LimitsPositioningTokens->{},
  FontSize->14,
  FontColor->RGBColor[0.2, 0, 0.4],
  Background->GrayLevel[1]],

Cell[StyleData["ExampleSection", "Printout"],
  CellMargins->{{50, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10],

Cell[StyleData["ExampleSection", "Proof"],
  CellMargins->{{50, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TheoremLabel"],
  CellMargins->{{12, 26}, {4, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  GroupPageBreakWithin->False,
  CellFrameMargins->{{Inherited, Inherited}, {4, 5}},
  LineSpacing->{1, 1},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0.2, 0.4]],

Cell[StyleData["TheoremLabel", "Printout"],
  CellMargins->{{12, 26}, {-1, 8}},
  FontSize->10,
  Background->GrayLevel[0.2]],

Cell[StyleData["TheoremLabel", "Proof"],
  CellMargins->{{12, 26}, {-1, 8}},
  FontSize->10,
  Background->GrayLevel[0.2]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellMargins->{{12, 26}, {8, 0}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  ShowStringCharacters->True,
  LimitsPositioningTokens->{},
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontColor->RGBColor[0.2, 0.2, 0.4]],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{12, 26}, {8, -1}},
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]],

Cell[StyleData["Theorem", "Proof"],
  CellMargins->{{12, 26}, {8, -1}},
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionLabel"],
  CellMargins->{{12, 26}, {4, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  GroupPageBreakWithin->False,
  CellFrameMargins->{{Inherited, Inherited}, {4, 5}},
  LineSpacing->{1, 1},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.4, 0, 0.6]],

Cell[StyleData["DefinitionLabel", "Printout"],
  Background->GrayLevel[0.2]],

Cell[StyleData["DefinitionLabel", "Proof"],
  Background->GrayLevel[0.2]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Definition"],
  CellMargins->{{12, 26}, {8, 0}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameLabelMargins->False,
  ShowStringCharacters->True,
  LimitsPositioningTokens->{},
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontColor->RGBColor[0.4, 0, 0.6],
  Background->GrayLevel[1]],

Cell[StyleData["Definition", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]],

Cell[StyleData["Definition", "Proof"],
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Information"],
  CellMargins->{{12, 26}, {8, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  ShowStringCharacters->True,
  LimitsPositioningTokens->{},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["Information", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]],

Cell[StyleData["Information", "Proof"],
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputLabel"],
  CellMargins->{{52, 35}, {0, 8}},
  PageBreakBelow->False,
  GroupPageBreakWithin->False,
  CellFrameMargins->{{Inherited, Inherited}, {2, 3}},
  LineSpacing->{1, 1},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  Background->RGBColor[0.2, 0.2, 0.6]],

Cell[StyleData["InputLabel", "Printout"],
  Background->GrayLevel[0.4]],

Cell[StyleData["InputLabel", "Proof"],
  Background->GrayLevel[0.4]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputLabel2"],
  CellMargins->{{52, 35}, {0, 8}},
  CellGroupingRules->{"SectionGrouping", 55},
  PageBreakBelow->False,
  GroupPageBreakWithin->False,
  CellFrameMargins->{{Inherited, Inherited}, {2, 3}},
  LineSpacing->{1, 1},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  Background->RGBColor[0.2, 0.2, 0.6]],

Cell[StyleData["InputLabel2", "Printout"],
  Background->GrayLevel[0.4]],

Cell[StyleData["InputLabel2", "Proof"],
  Background->GrayLevel[0.4]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExerciseBig"],
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 0}, {10, 8}},
  ParagraphIndent->-84,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0.8, 0.2],
  Background->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["ExerciseBig", "Printout"],
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0.2]],

Cell[StyleData["ExerciseBig", "Proof"],
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0.2]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Exercise"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{23, Inherited}, {4, 24}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  LimitsPositioningTokens->{},
  CounterIncrements->"Exercise",
  CounterAssignments->{{"NumberedExercise", 0}},
  FontFamily->"Times",
  FontSize->15,
  FontWeight->"Bold",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["Exercise", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0]],

Cell[StyleData["Exercise", "Proof"],
  FontSize->11,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExerciseLabel"],
  CellMargins->{{10, 10}, {0, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  GroupPageBreakWithin->False,
  LineSpacing->{1, 1},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  GridBoxOptions->{ColumnWidths->2,
  RowMinHeight->1.6}],

Cell[StyleData["ExerciseLabel", "Printout"]],

Cell[StyleData["ExerciseLabel", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExerciseFormula"],
  CellMargins->{{12, 10}, {5, 5}},
  CellGroupingRules->{"SectionGrouping", 60},
  DefaultFormatType->DefaultInputFormatType,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  LimitsPositioningTokens->{},
  FontFamily->"Times",
  FontSize->14],

Cell[StyleData["ExerciseFormula", "Printout"],
  ParagraphSpacing->{0, 6},
  FontSize->10],

Cell[StyleData["ExerciseFormula", "Proof"],
  ParagraphSpacing->{0, 6},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogHeader"],
  Editable->False,
  CellMargins->{{0, 0}, {0, -10}},
  Evaluatable->False,
  PageBreakBelow->False,
  CellFrameMargins->{{8, 8}, {10, 12}},
  LineSpacing->{1, 0},
  FontFamily->"Helvetica",
  FontSize->24,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[StyleData["DialogHeader", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->18,
  Background->GrayLevel[0.2]],

Cell[StyleData["DialogHeader", "Proof"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->18,
  Background->GrayLevel[0.2]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogTitle"],
  Editable->False,
  CellMargins->{{0, 8}, {0, 0}},
  Evaluatable->False,
  PageBreakBelow->False,
  CellFrameMargins->{{8, 8}, {5, 5}},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.4, 0, 0.4]],

Cell[StyleData["DialogTitle", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->12,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]],

Cell[StyleData["DialogTitle", "Proof"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->12,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogButtonBar"],
  Editable->False,
  CellMargins->{{8, 0}, {8, 4}},
  Evaluatable->False,
  CellGroupingRules->{"SectionGrouping", 60}],

Cell[StyleData["DialogButtonBar", "Printout"]],

Cell[StyleData["DialogButtonBar", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogText"],
  Editable->False,
  CellMargins->{{8, 4}, {0, 2}},
  Evaluatable->False,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["DialogText", "Printout"]],

Cell[StyleData["DialogText", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogEntryField"],
  CellFrame->{{1, 0}, {1, 1}},
  CellMargins->{{41, 0}, {6, 1}},
  Evaluatable->False,
  CellFrameMargins->{{8, 8}, {4, 4}},
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 1]],

Cell[StyleData["DialogEntryField", "Printout"]],

Cell[StyleData["DialogEntryField", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogTextEntryField"],
  CellFrame->{{1, 0}, {1, 1}},
  CellMargins->{{41, 0}, {6, 1}},
  Evaluatable->False,
  CellFrameMargins->{{8, 8}, {4, 4}},
  Background->GrayLevel[1]],

Cell[StyleData["DialogTextEntryField", "Printout"]],

Cell[StyleData["DialogTextEntryField", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogDoButton"],
  Editable->False,
  CellMargins->{{Inherited, 20}, {4, 8}},
  Evaluatable->False,
  CellFrameColor->RGBColor[1, 0.4, 0],
  TextAlignment->Right],

Cell[StyleData["DialogDoButton", "Printout"]],

Cell[StyleData["DialogDoButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogCodeCell"],
  CellMargins->{{0, 0}, {0, 0}},
  Evaluatable->False,
  FontFamily->"Courier",
  FontWeight->"Bold",
  Background->GrayLevel[0]],

Cell[StyleData["DialogCodeCell", "Printout"]],

Cell[StyleData["DialogCodeCell", "Proof"]]
}, Closed]],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["InlineKeys"],
  FontSize->16],

Cell[StyleData["InlineKeys", "Printout"],
  FontSize->12],

Cell[StyleData["InlineKeys", "Proof"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AnimationLabel"],
  CellMargins->{{52, 22}, {0, 8}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  GroupPageBreakWithin->False,
  CellFrameMargins->{{6, 6}, {2, 2}},
  LineSpacing->{1, 1},
  FontFamily->"Helvetica",
  FontSize->11,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  Background->RGBColor[0.2, 0.2, 0.6]],

Cell[StyleData["AnimationLabel", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}],

Cell[StyleData["AnimationLabel", "Proof"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{12, 0}, {0, 8}},
  Magnification->0.5],

Cell[StyleData["Picture", "Proof"],
  CellMargins->{{12, 0}, {0, 8}},
  Magnification->0.5]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PictureGroup"],
  CellMargins->{{52, 26}, {2, 2}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["PictureGroup", "Printout"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["PictureGroup", "Proof"],
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  LineSpacing->{1, 0},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->24,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0.8, 0.2],
  Background->GrayLevel[0]],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->24,
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  CellDingbat->None,
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"SectionGrouping", 10},
  CellFrameMargins->{{12, 0}, {8, 8}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[1, 0.8, 0.2]],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{20, 4}, {5, 20}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["IndexSection", "Printout"],
  CellMargins->{{12, 0}, {5, 20}},
  PageBreakBelow->False]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  CellMargins->{{21, 4}, {4, 4}},
  CellGroupingRules->{"SectionGrouping", 20},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{13, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentSubEntry"],
  CellMargins->{{60, 4}, {4, 0}},
  CellGroupingRules->{"SectionGrouping", 30},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["ContentSubEntry", "Printout"],
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->9]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\

The following styles are useful for numbered equations, figures, 
etc.  They automatically give the cell a FrameLabel containing a reference to \

a particular counter, and also increment that counter.
\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{60, 10}, {5, 5}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  LimitsPositioningTokens->{},
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontSize->14],

Cell[StyleData["NumberedEquation", "Printout"],
  TextAlignment->Center,
  FontSize->10],

Cell[StyleData["NumberedEquation", "Proof"],
  TextAlignment->Center,
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->6],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Buttons and Hyperlink Styles ", "Section"],

Cell["\<\

The cells below define styles useful for making hypertext 
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, 
or between Notebooks.
\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None",
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "Proof"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OpenGroup"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        FrontEnd`SelectedNotebook[ ], All, ButtonCell], 
      FrontEndToken[ "SelectionOpenAllGroups"]}]&),
  Active->True,
  ButtonFrame->"None",
  ButtonNote->ButtonData}],

Cell[StyleData["OpenGroup", "Printout"],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OpenGroup", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DoButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonEvaluator->Automatic,
  Background->GrayLevel[0],
  ButtonNote->"Do It!"}],

Cell[StyleData["DoButton", "Printout"]],

Cell[StyleData["DoButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UtilityButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->11,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  ButtonBoxOptions->{ButtonMinHeight->1.3,
  Background->RGBColor[0.2, 0, 0.4],
  ButtonNote->None}],

Cell[StyleData["UtilityButton", "Printout"]],

Cell[StyleData["UtilityButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SolverButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  ButtonMinHeight->1.2,
  Background->GrayLevel[0],
  ButtonNote->None}],

Cell[StyleData["SolverButton", "Printout"],
  CellMargins->{{0, 0}, {-10, -10}},
  FontSize->1,
  ButtonBoxOptions->{ButtonMinHeight->0,
  ButtonFrame->"None",
  Background->GrayLevel[1]}],

Cell[StyleData["SolverButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PaletteButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonFunction:>NotebookOpen[ "CalculusWiz.nb"],
  ButtonMinHeight->1.23,
  Background->RGBColor[0.4, 0, 0.4],
  ButtonNote->None}],

Cell[StyleData["PaletteButton", "Printout"],
  CellMargins->{{0, 0}, {-10, -10}},
  FontSize->1,
  ButtonBoxOptions->{ButtonMinHeight->0,
  ButtonFrame->"None",
  Background->GrayLevel[1]}],

Cell[StyleData["PaletteButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TemplateButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonEvaluator->Automatic,
  ButtonMinHeight->1.3,
  Background->RGBColor[0.2, 0, 0.4],
  ButtonNote->None}],

Cell[StyleData["TemplateButton", "Printout"],
  CellMargins->{{0, 0}, {-10, -10}},
  FontSize->1,
  ButtonBoxOptions->{ButtonMinHeight->0,
  ButtonFrame->"None",
  Background->GrayLevel[1]}],

Cell[StyleData["TemplateButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        ButtonNotebook[ ], Next, Cell], 
      FrontEnd`SelectionEvaluate[ 
        ButtonNotebook[ ]]}],
  Active->True,
  ButtonMinHeight->1.3,
  Background->GrayLevel[0],
  ButtonNote->None}],

Cell[StyleData["InputButton", "Printout"]],

Cell[StyleData["InputButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputButtonNull"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  ButtonBoxOptions->{Active->False,
  ButtonMinHeight->1.2,
  Background->GrayLevel[0],
  ButtonNote->None}],

Cell[StyleData["InputButtonNull", "Printout"],
  FontSize->7,
  ButtonBoxOptions->{ButtonMinHeight->0.8,
  Background->GrayLevel[0.500008]}],

Cell[StyleData["InputButtonNull", "Proof"],
  FontSize->7,
  ButtonBoxOptions->{ButtonMinHeight->0.8,
  Background->GrayLevel[0.500008]}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogAddOnsLink"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->11,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 1, 0.8],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  ButtonData:>"CalculusWiz 1.2.1",
  ButtonMinHeight->1.3,
  Background->RGBColor[0.2, 0, 0.4],
  ButtonNote->None}],

Cell[StyleData["DialogAddOnsLink", "Printout"]],

Cell[StyleData["DialogAddOnsLink", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AnimateButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEnd`SelectionMove[ 
        ButtonNotebook[ ], All, ButtonCell], 
      FrontEnd`SelectionMove[ 
        ButtonNotebook[ ], Next, CellGroup], 
      FrontEnd`SelectionAnimate[ 
        ButtonNotebook[ ]]}],
  Active->True,
  ButtonMinHeight->1.3,
  Background->GrayLevel[0],
  ButtonNote->None}],

Cell[StyleData["AnimateButton", "Printout"]],

Cell[StyleData["AnimateButton", "Proof"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["LiveAnimateButton"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      SelectionMove[ 
        ButtonNotebook[ ], All, ButtonCell], 
      NotebookFind[ 
        ButtonNotebook[ ], "PictureGroup", Next, CellStyle], 
      SelectionMove[ 
        ButtonNotebook[ ], All, CellGroup], 
      SelectionAnimate[ 
        ButtonNotebook[ ]]}],
  ButtonEvaluator->None,
  Active->True,
  ButtonMinHeight->1.3,
  Background->GrayLevel[0],
  ButtonNote->None}],

Cell[StyleData["LiveAnimateButton", "Printout"]],

Cell[StyleData["LiveAnimateButton", "Proof"]]
}, Closed]],

Cell["\<\

The following styles are for linking automatically to the on-line help \
system.
\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "Proof"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "Proof"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "Proof"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "Proof"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Miscellaneous", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherResourcesLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherResourcesLink", "Proof"],
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1106}, {0, 848}},
WindowSize->{650, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[StyleData["InheritFromParent"],
    CellGroupingRules->{"NormalGrouping", 9},
    ShowCellTags->True]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 65, "Subtitle"],
Cell[1816, 55, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2034, 63, 42, 0, 50, "Section"],
Cell[2079, 65, 131, 4, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2213, 71, 131, 4, 70, 32, 0, "StyleData", "All", "Brackets"],
Cell[2347, 77, 155, 4, 70, 32, 0, "StyleData", "All", "Printout"],
Cell[2505, 83, 200, 6, 70, 29, 0, "StyleData", "All", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[2742, 94, 35, 0, 30, "Section"],
Cell[2780, 96, 102, 5, 70, "Text"],
Cell[2885, 103, 1024, 23, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3946, 131, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[4009, 135, 291, 8, 70, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4303, 145, 165, 5, 70, 36, 0, "StyleData", "Title", "Printout"],
Cell[4471, 152, 162, 5, 70, 33, 0, "StyleData", "Title", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[4670, 162, 392, 11, 70, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5065, 175, 169, 5, 70, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[5237, 182, 166, 5, 70, 36, 0, "StyleData", "Subtitle", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[5440, 192, 395, 11, 70, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5838, 205, 139, 4, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[5980, 211, 136, 4, 70, 39, 0, "StyleData", "Subsubtitle", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[6153, 220, 396, 11, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[6552, 233, 141, 4, 70, 38, 0, "StyleData", "Section", "Printout"],
Cell[6696, 239, 138, 4, 70, 35, 0, "StyleData", "Section", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[6871, 248, 440, 12, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[7314, 262, 84, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[7401, 266, 81, 2, 70, 38, 0, "StyleData", "Subsection", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[7519, 273, 349, 9, 70, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[7871, 284, 120, 3, 70, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[7994, 289, 117, 3, 70, 41, 0, "StyleData", "Subsubsection", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[8148, 297, 316, 10, 70, 33, 0, "StyleData", "SubsectionIcon", "All",
  StyleMenuListing->None],
Cell[8467, 309, 105, 2, 70, 45, 0, "StyleData", "SubsectionIcon", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8621, 317, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[8685, 321, 226, 7, 70, 23, 0, "StyleData", "Text", "All"],
Cell[8914, 330, 114, 3, 70, 35, 0, "StyleData", "Text", "Printout"],
Cell[9031, 335, 134, 4, 70, 32, 0, "StyleData", "Text", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[9202, 344, 233, 7, 70, 28, 0, "StyleData", "SmallText", "All"],
Cell[9438, 353, 90, 2, 70, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[9531, 357, 87, 2, 70, 37, 0, "StyleData", "SmallText", "Proof"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9667, 365, 42, 0, 30, "Section"],
Cell[9712, 367, 247, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[9984, 378, 380, 11, 70, 24, 0, "StyleData", "Input", "All"],
Cell[10367, 391, 136, 3, 70, 36, 0, "StyleData", "Input", "Printout"],
Cell[10506, 396, 133, 3, 70, 33, 0, "StyleData", "Input", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[10676, 404, 427, 12, 70, 25, 0, "StyleData", "Input2", "All"],
Cell[11106, 418, 137, 3, 70, 37, 0, "StyleData", "Input2", "Printout"],
Cell[11246, 423, 134, 3, 70, 34, 0, "StyleData", "Input2", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[11417, 431, 442, 12, 70, 25, 0, "StyleData", "Output", "All"],
Cell[11862, 445, 88, 2, 70, 37, 0, "StyleData", "Output", "Printout"],
Cell[11953, 449, 85, 2, 70, 34, 0, "StyleData", "Output", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[12075, 456, 430, 12, 70, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[12508, 470, 81, 2, 70, 38, 0, "StyleData", "Message", "Printout"],
Cell[12592, 474, 78, 2, 70, 35, 0, "StyleData", "Message", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[12707, 481, 464, 13, 70, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[13174, 496, 87, 2, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[13264, 500, 84, 2, 70, 33, 0, "StyleData", "Print", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[13385, 507, 398, 12, 70, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[13786, 521, 166, 4, 70, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[13955, 527, 163, 4, 70, 36, 0, "StyleData", "Graphics", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[14155, 536, 398, 12, 70, 32, 0, "StyleData", "GraphicsGroup", "All",
  StyleMenuListing->None],
Cell[14556, 550, 171, 4, 70, 44, 0, "StyleData", "GraphicsGroup", \
"Printout"],
Cell[14730, 556, 168, 4, 70, 41, 0, "StyleData", "GraphicsGroup", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[14935, 565, 171, 5, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[15109, 572, 82, 2, 70, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[15194, 576, 79, 2, 70, 37, 0, "StyleData", "CellLabel", "Proof"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15322, 584, 52, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[15399, 588, 125, 4, 70, 25, 0, "StyleData", "Author", "All",
  StyleMenuListing->None],
Cell[15527, 594, 115, 3, 70, 37, 0, "StyleData", "Author", "Printout"],
Cell[15645, 599, 112, 3, 70, 34, 0, "StyleData", "Author", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[15794, 607, 132, 4, 70, 28, 0, "StyleData", "Copyright", "All",
  StyleMenuListing->None],
Cell[15929, 613, 89, 2, 70, 40, 0, "StyleData", "Copyright", "Printout"],
Cell[16021, 617, 86, 2, 70, 37, 0, "StyleData", "Copyright", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[16144, 624, 435, 12, 70, 32, 0, "StyleData", "EndOfExercise", "All"],
Cell[16582, 638, 95, 2, 70, 44, 0, "StyleData", "EndOfExercise", "Printout"],
Cell[16680, 642, 92, 2, 70, 41, 0, "StyleData", "EndOfExercise", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[16809, 649, 188, 6, 70, 31, 0, "StyleData", "IndentedText", "All"],
Cell[17000, 657, 121, 3, 70, 43, 0, "StyleData", "IndentedText", "Printout"],
Cell[17124, 662, 118, 3, 70, 40, 0, "StyleData", "IndentedText", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[17279, 670, 280, 8, 70, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[17562, 680, 89, 2, 70, 45, 0, "StyleData", "DisplayFormula", \
"Printout"],
Cell[17654, 684, 86, 2, 70, 42, 0, "StyleData", "DisplayFormula", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[17777, 691, 308, 9, 70, 33, 0, "StyleData", "ExampleSection", "All"],
Cell[18088, 702, 123, 3, 70, 45, 0, "StyleData", "ExampleSection", \
"Printout"],
Cell[18214, 707, 120, 3, 70, 42, 0, "StyleData", "ExampleSection", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[18371, 715, 376, 11, 70, 31, 0, "StyleData", "TheoremLabel", "All"],
Cell[18750, 728, 125, 3, 70, 43, 0, "StyleData", "TheoremLabel", "Printout"],
Cell[18878, 733, 122, 3, 70, 40, 0, "StyleData", "TheoremLabel", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[19037, 741, 375, 10, 70, 26, 0, "StyleData", "Theorem", "All"],
Cell[19415, 753, 152, 4, 70, 38, 0, "StyleData", "Theorem", "Printout"],
Cell[19570, 759, 149, 4, 70, 35, 0, "StyleData", "Theorem", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[19756, 768, 377, 11, 70, 34, 0, "StyleData", "DefinitionLabel", "All"],
Cell[20136, 781, 76, 1, 70, 46, 0, "StyleData", "DefinitionLabel", \
"Printout"],
Cell[20215, 784, 73, 1, 70, 43, 0, "StyleData", "DefinitionLabel", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[20325, 790, 436, 12, 70, 29, 0, "StyleData", "Definition", "All"],
Cell[20764, 804, 119, 3, 70, 41, 0, "StyleData", "Definition", "Printout"],
Cell[20886, 809, 116, 3, 70, 38, 0, "StyleData", "Definition", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[21039, 817, 400, 11, 70, 30, 0, "StyleData", "Information", "All",
  StyleMenuListing->None],
Cell[21442, 830, 120, 3, 70, 42, 0, "StyleData", "Information", "Printout"],
Cell[21565, 835, 117, 3, 70, 39, 0, "StyleData", "Information", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[21719, 843, 335, 10, 70, 29, 0, "StyleData", "InputLabel", "All"],
Cell[22057, 855, 71, 1, 70, 41, 0, "StyleData", "InputLabel", "Printout"],
Cell[22131, 858, 68, 1, 70, 38, 0, "StyleData", "InputLabel", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[22236, 864, 382, 11, 70, 30, 0, "StyleData", "InputLabel2", "All"],
Cell[22621, 877, 72, 1, 70, 42, 0, "StyleData", "InputLabel2", "Printout"],
Cell[22696, 880, 69, 1, 70, 39, 0, "StyleData", "InputLabel2", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[22802, 886, 431, 12, 70, 30, 0, "StyleData", "ExerciseBig", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[23236, 900, 140, 4, 70, 42, 0, "StyleData", "ExerciseBig", "Printout"],
Cell[23379, 906, 137, 4, 70, 39, 0, "StyleData", "ExerciseBig", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[23553, 915, 401, 11, 70, 27, 0, "StyleData", "Exercise", "All",
  CounterIncrements->"Exercise",
  CounterAssignments->{{"NumberedExercise", 0}}],
Cell[23957, 928, 82, 2, 70, 39, 0, "StyleData", "Exercise", "Printout"],
Cell[24042, 932, 79, 2, 70, 36, 0, "StyleData", "Exercise", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[24158, 939, 342, 11, 70, 32, 0, "StyleData", "ExerciseLabel", "All"],
Cell[24503, 952, 44, 0, 70, 44, 0, "StyleData", "ExerciseLabel", "Printout"],
Cell[24550, 954, 41, 0, 70, 41, 0, "StyleData", "ExerciseLabel", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[24628, 959, 281, 8, 70, 34, 0, "StyleData", "ExerciseFormula", "All"],
Cell[24912, 969, 90, 2, 70, 46, 0, "StyleData", "ExerciseFormula", \
"Printout"],
Cell[25005, 973, 87, 2, 70, 43, 0, "StyleData", "ExerciseFormula", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[25129, 980, 315, 11, 70, 31, 0, "StyleData", "DialogHeader", "All"],
Cell[25447, 993, 122, 3, 70, 43, 0, "StyleData", "DialogHeader", "Printout"],
Cell[25572, 998, 119, 3, 70, 40, 0, "StyleData", "DialogHeader", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[25728, 1006, 319, 11, 70, 30, 0, "StyleData", "DialogTitle", "All"],
Cell[26050, 1019, 153, 4, 70, 42, 0, "StyleData", "DialogTitle", "Printout"],
Cell[26206, 1025, 150, 4, 70, 39, 0, "StyleData", "DialogTitle", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[26393, 1034, 154, 4, 70, 34, 0, "StyleData", "DialogButtonBar", "All"],
Cell[26550, 1040, 46, 0, 70, 46, 0, "StyleData", "DialogButtonBar", \
"Printout"],
Cell[26599, 1042, 43, 0, 70, 43, 0, "StyleData", "DialogButtonBar", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[26679, 1047, 203, 7, 70, 29, 0, "StyleData", "DialogText", "All"],
Cell[26885, 1056, 41, 0, 70, 41, 0, "StyleData", "DialogText", "Printout"],
Cell[26929, 1058, 38, 0, 70, 38, 0, "StyleData", "DialogText", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[27004, 1063, 340, 10, 70, 35, 0, "StyleData", "DialogEntryField", \
"All"],
Cell[27347, 1075, 47, 0, 70, 47, 0, "StyleData", "DialogEntryField", \
"Printout"],
Cell[27397, 1077, 44, 0, 70, 44, 0, "StyleData", "DialogEntryField", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[27478, 1082, 192, 5, 70, 39, 0, "StyleData", "DialogTextEntryField", \
"All"],
Cell[27673, 1089, 51, 0, 70, 51, 0, "StyleData", "DialogTextEntryField", \
"Printout"],
Cell[27727, 1091, 48, 0, 70, 48, 0, "StyleData", "DialogTextEntryField", \
"Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[27812, 1096, 179, 5, 70, 33, 0, "StyleData", "DialogDoButton", "All"],
Cell[27994, 1103, 45, 0, 70, 45, 0, "StyleData", "DialogDoButton", \
"Printout"],
Cell[28042, 1105, 42, 0, 70, 42, 0, "StyleData", "DialogDoButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[28121, 1110, 163, 5, 70, 33, 0, "StyleData", "DialogCodeCell", "All"],
Cell[28287, 1117, 45, 0, 70, 45, 0, "StyleData", "DialogCodeCell", \
"Printout"],
Cell[28335, 1119, 42, 0, 70, 42, 0, "StyleData", "DialogCodeCell", "Proof"]
}, Closed]],
Cell[28392, 1122, 115, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[28532, 1129, 45, 1, 70, 29, 0, "StyleData", "InlineKeys", "All"],
Cell[28580, 1132, 57, 1, 70, 41, 0, "StyleData", "InlineKeys", "Printout"],
Cell[28640, 1135, 54, 1, 70, 38, 0, "StyleData", "InlineKeys", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[28731, 1141, 369, 11, 70, 33, 0, "StyleData", "AnimationLabel", "All"],
Cell[29103, 1154, 79, 1, 70, 45, 0, "StyleData", "AnimationLabel", \
"Printout"],
Cell[29185, 1157, 76, 1, 70, 42, 0, "StyleData", "AnimationLabel", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[29298, 1163, 127, 3, 70, 26, 0, "StyleData", "Picture", "All",
  StyleMenuListing->None],
Cell[29428, 1168, 94, 2, 70, 38, 0, "StyleData", "Picture", "Printout"],
Cell[29525, 1172, 91, 2, 70, 35, 0, "StyleData", "Picture", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[29653, 1179, 175, 4, 70, 31, 0, "StyleData", "PictureGroup", "All"],
Cell[29831, 1185, 170, 4, 70, 43, 0, "StyleData", "PictureGroup", \
"Printout"],
Cell[30004, 1191, 167, 4, 70, 40, 0, "StyleData", "PictureGroup", "Proof"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30220, 1201, 37, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[30282, 1205, 268, 9, 70, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[30553, 1216, 173, 5, 70, 44, 0, "StyleData", "ContentsTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30763, 1226, 328, 10, 70, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[31094, 1238, 106, 2, 70, 46, 0, "StyleData", "ContentsSection", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31237, 1245, 191, 6, 70, 31, 0, "StyleData", "IndexSection", "All",
  StyleMenuListing->None],
Cell[31431, 1253, 103, 2, 70, 43, 0, "StyleData", "IndexSection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31571, 1260, 176, 5, 70, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[31750, 1267, 73, 1, 70, 39, 0, "StyleData", "Contents", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31860, 1273, 179, 5, 70, 34, 0, "StyleData", "ContentSubEntry", "All",
  StyleMenuListing->None],
Cell[32042, 1280, 85, 2, 70, 46, 0, "StyleData", "ContentSubEntry", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32164, 1287, 108, 3, 70, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[32275, 1292, 85, 2, 70, 36, 0, "StyleData", "Index", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32397, 1299, 116, 3, 70, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[32516, 1304, 93, 2, 70, 44, 0, "StyleData", "IndexSubentry", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32658, 1312, 49, 0, 30, "Section"],
Cell[32710, 1314, 227, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[32962, 1325, 416, 11, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[33381, 1338, 88, 2, 70, 47, 0, "StyleData", "NumberedEquation", \
"Printout"],
Cell[33472, 1342, 85, 2, 70, 44, 0, "StyleData", "NumberedEquation", "Proof"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33606, 1350, 49, 0, 30, "Section"],
Cell[33658, 1352, 149, 5, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[33810, 1359, 126, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[33939, 1365, 152, 5, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[34128, 1375, 48, 0, 30, "Section"],
Cell[34179, 1377, 184, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[34388, 1387, 325, 9, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[34716, 1398, 107, 2, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[34826, 1402, 64, 1, 70, 37, 0, "StyleData", "Hyperlink", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[34927, 1408, 393, 10, 70, 28, 0, "StyleData", "OpenGroup", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35323, 1420, 80, 1, 70, 40, 0, "StyleData", "OpenGroup", "Printout"],
Cell[35406, 1423, 37, 0, 70, 37, 0, "StyleData", "OpenGroup", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[35480, 1428, 247, 8, 70, 27, 0, "StyleData", "DoButton", "All",
  StyleMenuListing->None],
Cell[35730, 1438, 39, 0, 70, 39, 0, "StyleData", "DoButton", "Printout"],
Cell[35772, 1440, 36, 0, 70, 36, 0, "StyleData", "DoButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[35845, 1445, 258, 8, 70, 32, 0, "StyleData", "UtilityButton", "All",
  StyleMenuListing->None],
Cell[36106, 1455, 44, 0, 70, 44, 0, "StyleData", "UtilityButton", \
"Printout"],
Cell[36153, 1457, 41, 0, 70, 41, 0, "StyleData", "UtilityButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[36231, 1462, 319, 10, 70, 31, 0, "StyleData", "SolverButton", "All",
  StyleMenuListing->None],
Cell[36553, 1474, 188, 5, 70, 43, 0, "StyleData", "SolverButton", \
"Printout"],
Cell[36744, 1481, 40, 0, 70, 40, 0, "StyleData", "SolverButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[36821, 1486, 303, 9, 70, 32, 0, "StyleData", "PaletteButton", "All",
  StyleMenuListing->None],
Cell[37127, 1497, 189, 5, 70, 44, 0, "StyleData", "PaletteButton", \
"Printout"],
Cell[37319, 1504, 41, 0, 70, 41, 0, "StyleData", "PaletteButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[37397, 1509, 282, 9, 70, 33, 0, "StyleData", "TemplateButton", "All",
  StyleMenuListing->None],
Cell[37682, 1520, 190, 5, 70, 45, 0, "StyleData", "TemplateButton", \
"Printout"],
Cell[37875, 1527, 42, 0, 70, 42, 0, "StyleData", "TemplateButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[37954, 1532, 514, 16, 70, 30, 0, "StyleData", "InputButton", "All",
  StyleMenuListing->None],
Cell[38471, 1550, 42, 0, 70, 42, 0, "StyleData", "InputButton", "Printout"],
Cell[38516, 1552, 39, 0, 70, 39, 0, "StyleData", "InputButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[38592, 1557, 268, 9, 70, 34, 0, "StyleData", "InputButtonNull", "All",
  StyleMenuListing->None],
Cell[38863, 1568, 140, 3, 70, 46, 0, "StyleData", "InputButtonNull", \
"Printout"],
Cell[39006, 1573, 137, 3, 70, 43, 0, "StyleData", "InputButtonNull", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[39180, 1581, 386, 11, 70, 35, 0, "StyleData", "DialogAddOnsLink", "All",
  StyleMenuListing->None],
Cell[39569, 1594, 47, 0, 70, 47, 0, "StyleData", "DialogAddOnsLink", \
"Printout"],
Cell[39619, 1596, 44, 0, 70, 44, 0, "StyleData", "DialogAddOnsLink", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[39700, 1601, 512, 16, 70, 32, 0, "StyleData", "AnimateButton", "All",
  StyleMenuListing->None],
Cell[40215, 1619, 44, 0, 70, 44, 0, "StyleData", "AnimateButton", \
"Printout"],
Cell[40262, 1621, 41, 0, 70, 41, 0, "StyleData", "AnimateButton", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[40340, 1626, 596, 19, 70, 36, 0, "StyleData", "LiveAnimateButton", "All",
  
  StyleMenuListing->None],
Cell[40939, 1647, 48, 0, 70, 48, 0, "StyleData", "LiveAnimateButton", \
"Printout"],
Cell[40990, 1649, 45, 0, 70, 45, 0, "StyleData", "LiveAnimateButton", \
"Proof"]
}, Closed]],
Cell[41050, 1652, 106, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[41181, 1661, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41500, 1671, 110, 2, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"],
Cell[41613, 1675, 67, 1, 70, 40, 0, "StyleData", "MainBookLink", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[41717, 1681, 335, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42055, 1692, 108, 2, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"],
Cell[42166, 1696, 65, 1, 70, 38, 0, "StyleData", "AddOnsLink", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[42268, 1702, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42616, 1713, 110, 2, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"],
Cell[42729, 1717, 67, 1, 70, 40, 0, "StyleData", "RefGuideLink", "Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[42833, 1723, 330, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[43166, 1733, 116, 2, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[43285, 1737, 73, 1, 70, 46, 0, "StyleData", "GettingStartedLink", \
"Proof"]
}, Closed]],

Cell[CellGroupData[{
Cell[43395, 1743, 329, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[43727, 1753, 116, 2, 70, 49, 0, "StyleData", "OtherResourcesLink", \
"Printout"],
Cell[43846, 1757, 73, 1, 70, 46, 0, "StyleData", "OtherResourcesLink", \
"Proof"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

