(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25081,        834]*)
(*NotebookOutlinePosition[     25716,        856]*)
(*  CellTagsIndexPosition[     25672,        852]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "SansSerif"],
  PageWidth->WindowWidth,
  ScriptMinSize->7,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->7,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "SansSerifPrintout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontFamily->"Helvetica",
  FontSize->8,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  DefaultNewCellStyle->"Text",
  DefaultDuplicateCellStyle->"Text",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["H1"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  LineSpacing->{1, 13},
  CounterIncrements->"H1",
  CounterAssignments->{{"H2", 0}, {"H3", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H4", 0}, {"H5", 0}, {"H6", 0}},
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["H1", "SansSerif"],
  FontSize->30,
  FontWeight->"Bold"],

Cell[StyleData["H1", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->30],

Cell[StyleData["H1", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->26]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H2"],
  CellMargins->{{12, Inherited}, {10, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"H2",
  CounterAssignments->{{"H3", 0}, {"H4", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H5", 0}, {"H6", 0}},
  FontSize->24,
  FontWeight->"Bold"],

Cell[StyleData["H2", "SansSerif"],
  FontSize->20],

Cell[StyleData["H2", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->20],

Cell[StyleData["H2", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H3"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"H3",
  CounterAssignments->{{"H4", 0}, {"H5", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H6", 0}},
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["H3", "SansSerif"],
  FontSize->16],

Cell[StyleData["H3", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->16],

Cell[StyleData["H3", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H4"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"H4",
  CounterAssignments->{{"H5", 0}, {"H6", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["H4", "SansSerif"],
  FontSize->12],

Cell[StyleData["H4", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->12],

Cell[StyleData["H4", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H5"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"H5",
  CounterAssignments->{{"H6", 0}},
  FontWeight->"Bold"],

Cell[StyleData["H5", "SansSerif"]],

Cell[StyleData["H5", "Printout"],
  CellMargins->{{2, 10}, {8, 10}}],

Cell[StyleData["H5", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H6"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"H6",
  FontSize->10,
  FontWeight->"Bold"],

Cell[StyleData["H6", "SansSerif"],
  FontSize->9,
  FontTracking->"Extended"],

Cell[StyleData["H6", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->8.5],

Cell[StyleData["H6", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->7.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Body"],
  CellMargins->{{14, 10}, {7, 7}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  LineSpacing->{1, 3},
  CounterIncrements->"Body"],

Cell[StyleData["Body", "SansSerif"]],

Cell[StyleData["Body", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["Body", "SansSerifPrintout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["LI"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{23, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"LI"],

Cell[StyleData["LI", "SansSerif"],
  CellMargins->{{25, 10}, {7, 7}}],

Cell[StyleData["LI", "Printout"],
  CellMargins->{{12, 2}, {6, 6}}],

Cell[StyleData["LI", "SansSerifPrintout"],
  CellMargins->{{12, 2}, {6, 6}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "SansSerif"],
  FontSize->12],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9],

Cell[StyleData["Input", "SansSerifPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "SansSerif"],
  FontSize->12],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "SansSerifPrintout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "SansSerif"],
  FontSize->12],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "SansSerifPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "SansSerif"],
  FontSize->12],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8],

Cell[StyleData["Print", "SansSerifPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "SansSerif"],
  FontSize->12],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "SansSerifPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "SansSerif"]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "SansSerifPrintout"],
  FontSize->7,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "SansSerif"]],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "SansSerif"]],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "SansSerif"]],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "SansSerif"]],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "SansSerif"]],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "SansSerif"]],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1106}, {0, 848}},
WindowSize->{500, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 65, "Subtitle"],
Cell[1767, 54, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[1985, 62, 42, 0, 56, "Section"],
Cell[2030, 64, 77, 2, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2110, 68, 122, 4, 70, 33, 0, "StyleData", "All", "SansSerif"],
Cell[2235, 74, 140, 4, 70, 32, 0, "StyleData", "All", "Printout"],
Cell[2378, 80, 175, 5, 70, 41, 0, "StyleData", "All", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2590, 90, 35, 0, 36, "Section"],
Cell[2628, 92, 101, 3, 70, "Text"],
Cell[2732, 97, 494, 13, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3263, 115, 38, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[3326, 119, 1207, 27, 70, 21, 0, "StyleData", "H1", "All",
  CounterIncrements->"H1",
  CounterAssignments->{{"H2", 0}, {"H3", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H4", 0}, {"H5", 0}, {"H6", 0}}],
Cell[4536, 148, 72, 2, 70, 34, 0, "StyleData", "H1", "SansSerif"],
Cell[4611, 152, 85, 2, 70, 33, 0, "StyleData", "H1", "Printout"],
Cell[4699, 156, 94, 2, 70, 42, 0, "StyleData", "H1", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4830, 163, 1173, 26, 70, 21, 0, "StyleData", "H2", "All",
  CounterIncrements->"H2",
  CounterAssignments->{{"H3", 0}, {"H4", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H5", 0}, {"H6", 0}}],
Cell[6006, 191, 50, 1, 70, 34, 0, "StyleData", "H2", "SansSerif"],
Cell[6059, 194, 85, 2, 70, 33, 0, "StyleData", "H2", "Printout"],
Cell[6147, 198, 94, 2, 70, 42, 0, "StyleData", "H2", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6278, 205, 1162, 26, 70, 21, 0, "StyleData", "H3", "All",
  CounterIncrements->"H3",
  CounterAssignments->{{"H4", 0}, {"H5", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H6", 0}}],
Cell[7443, 233, 50, 1, 70, 34, 0, "StyleData", "H3", "SansSerif"],
Cell[7496, 236, 84, 2, 70, 33, 0, "StyleData", "H3", "Printout"],
Cell[7583, 240, 93, 2, 70, 42, 0, "StyleData", "H3", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7713, 247, 1146, 25, 70, 21, 0, "StyleData", "H4", "All",
  CounterIncrements->"H4",
  CounterAssignments->{{"H5", 0}, {"H6", 0}, {"Equation", 0}, {
      "Figure", 0}}],
Cell[8862, 274, 50, 1, 70, 34, 0, "StyleData", "H4", "SansSerif"],
Cell[8915, 277, 84, 2, 70, 33, 0, "StyleData", "H4", "Printout"],
Cell[9002, 281, 93, 2, 70, 42, 0, "StyleData", "H4", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9132, 288, 1087, 24, 70, 21, 0, "StyleData", "H5", "All",
  CounterIncrements->"H5",
  CounterAssignments->{{"H6", 0}}],
Cell[10222, 314, 34, 0, 70, 34, 0, "StyleData", "H5", "SansSerif"],
Cell[10259, 316, 68, 1, 70, 33, 0, "StyleData", "H5", "Printout"],
Cell[10330, 319, 77, 1, 70, 42, 0, "StyleData", "H5", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10444, 325, 1068, 24, 70, 21, 0, "StyleData", "H6", "All",
  CounterIncrements->"H6"],
Cell[11515, 351, 77, 2, 70, 34, 0, "StyleData", "H6", "SansSerif"],
Cell[11595, 355, 85, 2, 70, 33, 0, "StyleData", "H6", "Printout"],
Cell[11683, 359, 94, 2, 70, 42, 0, "StyleData", "H6", "SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11826, 367, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[11890, 371, 977, 21, 70, 23, 0, "StyleData", "Body", "All",
  CounterIncrements->"Body"],
Cell[12870, 394, 36, 0, 70, 36, 0, "StyleData", "Body", "SansSerif"],
Cell[12909, 396, 68, 1, 70, 35, 0, "StyleData", "Body", "Printout"],
Cell[12980, 399, 77, 1, 70, 44, 0, "StyleData", "Body", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13094, 405, 145, 4, 70, 21, 0, "StyleData", "LI", "All",
  CounterIncrements->"LI"],
Cell[13242, 411, 69, 1, 70, 34, 0, "StyleData", "LI", "SansSerif"],
Cell[13314, 414, 67, 1, 70, 33, 0, "StyleData", "LI", "Printout"],
Cell[13384, 417, 76, 1, 70, 42, 0, "StyleData", "LI", "SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13509, 424, 42, 0, 36, "Section"],
Cell[13554, 426, 248, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[13827, 435, 659, 18, 70, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[14489, 455, 53, 1, 70, 37, 0, "StyleData", "Input", "SansSerif"],
Cell[14545, 458, 130, 3, 70, 36, 0, "StyleData", "Input", "Printout"],
Cell[14678, 463, 94, 2, 70, 45, 0, "StyleData", "Input", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14809, 470, 601, 16, 70, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[15413, 488, 54, 1, 70, 38, 0, "StyleData", "Output", "SansSerif"],
Cell[15470, 491, 86, 2, 70, 37, 0, "StyleData", "Output", "Printout"],
Cell[15559, 495, 95, 2, 70, 46, 0, "StyleData", "Output", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15691, 502, 617, 16, 70, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[16311, 520, 55, 1, 70, 39, 0, "StyleData", "Message", "SansSerif"],
Cell[16369, 523, 138, 3, 70, 38, 0, "StyleData", "Message", "Printout"],
Cell[16510, 528, 147, 3, 70, 47, 0, "StyleData", "Message", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16694, 536, 614, 16, 70, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[17311, 554, 53, 1, 70, 37, 0, "StyleData", "Print", "SansSerif"],
Cell[17367, 557, 109, 2, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[17479, 561, 118, 2, 70, 45, 0, "StyleData", "Print", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17634, 568, 440, 12, 70, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[18077, 582, 56, 1, 70, 40, 0, "StyleData", "Graphics", "SansSerif"],
Cell[18136, 585, 137, 3, 70, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[18276, 590, 146, 3, 70, 48, 0, "StyleData", "Graphics", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18459, 598, 128, 4, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[18590, 604, 41, 0, 70, 41, 0, "StyleData", "CellLabel", "SansSerif"],
Cell[18634, 606, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[18767, 612, 91, 2, 70, 49, 0, "StyleData", "CellLabel", \
"SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18907, 620, 35, 0, 36, "Section"],
Cell[18945, 622, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[19154, 630, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19459, 640, 41, 0, 70, 41, 0, "StyleData", "Hyperlink", "SansSerif"],
Cell[19503, 642, 107, 2, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[19613, 646, 116, 2, 70, 49, 0, "StyleData", "Hyperlink", \
"SansSerifPrintout"]
}, Closed]],
Cell[19744, 651, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[19873, 658, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[20192, 668, 44, 0, 70, 44, 0, "StyleData", "MainBookLink", "SansSerif"],
Cell[20239, 670, 110, 2, 70, 43, 0, "StyleData", "MainBookLink", "Printout"],
Cell[20352, 674, 119, 2, 70, 52, 0, "StyleData", "MainBookLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20508, 681, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[20848, 692, 42, 0, 70, 42, 0, "StyleData", "AddOnsLink", "SansSerif"],
Cell[20893, 694, 107, 2, 70, 40, 0, "StyleData", "AddOnLink", "Printout"],
Cell[21003, 698, 116, 2, 70, 49, 0, "StyleData", "AddOnLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21156, 705, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[21504, 716, 44, 0, 70, 44, 0, "StyleData", "RefGuideLink", "SansSerif"],
Cell[21551, 718, 110, 2, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"],
Cell[21664, 722, 119, 2, 70, 52, 0, "StyleData", "RefGuideLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21820, 729, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[22151, 739, 50, 0, 70, 50, 0, "StyleData", "GettingStartedLink", \
"SansSerif"],
Cell[22204, 741, 116, 2, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[22323, 745, 125, 2, 70, 58, 0, "StyleData", "GettingStartedLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22485, 752, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[22820, 762, 52, 0, 70, 52, 0, "StyleData", "OtherInformationLink", \
"SansSerif"],
Cell[22875, 764, 118, 2, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"],
Cell[22996, 768, 127, 2, 70, 60, 0, "StyleData", "OtherInformationLink", \
"SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23172, 776, 33, 0, 36, "Section"],
Cell[23208, 778, 121, 3, 70, "Text"],
Cell[23332, 783, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23561, 790, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23859, 799, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24262, 810, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24652, 821, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

