(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     39310,       1349]*)
(*NotebookOutlinePosition[     39953,       1371]*)
(*  CellTagsIndexPosition[     39909,       1367]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Color"->RGBColor[0.4, 0, 0.239994]},
  ScriptMinSize->9,
  Background->RGBColor[1, 0.960006, 0.900008]],

Cell[StyleData[All, "SlideShow"],
  PageWidth->WindowWidth,
  ScrollingOptions->{"PagewiseDisplay"->True},
  CellBracketOptions->{"Color"->RGBColor[0.744411, 0.47155, 0.371542]},
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Color"->RGBColor[0.744411, 0.47155, 0.371542]},
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellLabel->False,
  ImageSize->{200, 200},
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->{{0, 0}, {0, 0.25}},
  CellMargins->{{18, 10}, {0, 20}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameMargins->6,
  CellFrameColor->GrayLevel[0],
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  LineSpacing->{0.95, 13},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->RGBColor[0.4, 0, 0.239994]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{20, 10}, {2, 20}},
  CellFrameMargins->5,
  FontColor->RGBColor[0.744411, 0.47155, 0.371542]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{18, 30}, {0, 0}},
  CellFrameMargins->4,
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{20, 30}, {2, 10}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 4}, {8, 4}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  LineSpacing->{1, 0},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->24],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{20, 10}, {2, 10}}],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{18, 30}, {0, 10}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section 1"],
  CellFrame->{{0, 0}, {0, 3}},
  CellMargins->{{18, 10}, {10, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 4}, {8, 4}},
  CellFrameColor->RGBColor[0.4, 0, 0.239994],
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Section 1", "Presentation"],
  CellMargins->{{20, 10}, {6, 30}},
  CellFrameMargins->5],

Cell[StyleData["Section 1", "Printout"],
  CellMargins->{{18, 30}, {4, 30}},
  CellFrameMargins->4,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0, 0.25}},
  CellMargins->{{18, 10}, {10, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->4,
  CellFrameColor->RGBColor[0.4, 0, 0.239994],
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{20, 10}, {0, 30}}],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{18, 30}, {0, 30}},
  CellFrameMargins->5,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{38, 30}, {2, 20}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{35, 30}, {0, 20}}],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{18, 30}, {0, 10}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{55, 30}, {4, 10}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{31, 30}, {0, 12}}],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{18, 30}, {0, 12}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{55, 10}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 2},
  FontFamily->"Times"],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{20, 10}, {6, 6}},
  TextAlignment->Left,
  TextJustification->0,
  LineSpacing->{1.3, 0},
  FontSize->14],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellMargins->{{55, 10}, {2, 6}},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 2},
  FontFamily->"Helvetica",
  FontSize->10,
  FontColor->RGBColor[0, 0, 0.4]],

Cell[StyleData["Commentary", "Presentation"],
  CellMargins->{{60, 30}, {2, 6}},
  TextJustification->1,
  LineSpacing->{1.3, 0},
  FontSize->12],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{18, 30}, {3, 0}},
  LineSpacing->{1, 3},
  FontFamily->"Times",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->{{1, 1}, {0, 1}},
  CellMargins->{{55, 10}, {0, 0}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelPositioning->Automatic,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  FontSize->12,
  FontWeight->"Bold",
  Background->GrayLevel[0.966674]],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{60, 10}, {0, 10}},
  Background->GrayLevel[0.850004]],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{55, 10}, {0, 10}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->10,
  Background->GrayLevel[0.850004]]
}, Closed]],

Cell[StyleData["InlineInput"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->{{1, 1}, {1, 0}},
  CellMargins->{{55, 10}, {15, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  FontSize->12,
  Background->GrayLevel[0.850004]],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{60, Inherited}, {10, 0}}],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{55, Inherited}, {10, 0}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputOnly"],
  CellFrame->1,
  CellMargins->{{55, 10}, {15, 0}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelPositioning->Automatic,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  FontSize->12,
  FontWeight->"Bold",
  Background->GrayLevel[0.966674]],

Cell[StyleData["InputOnly", "Presentation"],
  CellMargins->{{60, Inherited}, {10, 10}}],

Cell[StyleData["InputOnly", "Printout"],
  CellMargins->{{55, Inherited}, {10, 10}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellFrame->{{1, 1}, {0, 0}},
  CellDingbat->"\[LongDash]",
  CellMargins->{{55, 10}, {0, 0}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontSlant->"Oblique",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{60, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{55, Inherited}, {0, 0}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{55, 26}, {1, 6}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  TextAlignment->Left,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  StyleMenuListing->None,
  Background->GrayLevel[0.700008]],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{60, Inherited}, {10, 2}}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{54, Inherited}, {2, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellFrame->{{1, 1}, {0, 0}},
  CellMargins->{{55, 10}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  Background->GrayLevel[0.850004]],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{60, Inherited}, {0, 0}},
  ImageMargins->{{10, 10}, {10, 10}}],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{55, Inherited}, {0, 0}},
  ImageSize->{0.0625, 0.0625}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontSlant->"Oblique",
  FontColor->RGBColor[0.6, 0, 0.6]],

Cell[StyleData["CellLabel", "Presentation"],
  CellMargins->{{18, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["CellLabel", "Printout"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unique Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{20, 30}, {45, 5}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 4}, {8, 4}},
  LineSpacing->{1, 0},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Author", "Presentation"],
  CellMargins->{{20, 30}, {45, 10}}],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{18, 30}, {45, 5}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Abstract"],
  CellFrame->False,
  CellMargins->{{18, 140}, {4, 30}},
  Hyphenation->True,
  LineSpacing->{0.9, 0},
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["Abstract", "Presentation"],
  CellFrame->True,
  CellMargins->{{20, 10}, {Inherited, 30}}],

Cell[StyleData["Abstract", "Printout"],
  LineSpacing->{1, 2},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{55, 10}, {5, 3}},
  PageBreakAbove->False,
  Hyphenation->True,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Presentation"],
  CellMargins->{{60, 65}, {6, 4}},
  FontSize->10],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{55, 55}, {5, 4}},
  LineSpacing->{1, 2},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{24, 40}, {6, 6}},
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 0},
  FontFamily->"Times"],

Cell[StyleData["Reference", "Presentation"],
  CellMargins->{{20, 40}, {Inherited, 6}},
  TextJustification->0,
  LineSpacing->{1, 4},
  FontSize->12],

Cell[StyleData["Reference", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PictureGroup"],
  CellFrame->{{1, 1}, {0, 0}},
  CellMargins->{{55, Inherited}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  ShowCellLabel->False,
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  Background->GrayLevel[0.850004]],

Cell[StyleData["PictureGroup", "Presentation"],
  CellMargins->{{60, Inherited}, {0, 0}},
  ImageMargins->{{10, 10}, {10, 10}}],

Cell[StyleData["PictureGroup", "Printout"],
  CellMargins->{{55, Inherited}, {0, 0}},
  ImageSize->{0.0625, 0.0625}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"],
  FontSize->16],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Presentation"],
  FontSize->16],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Presentation"],
  FontSize->16],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Presentation"],
  FontSize->16],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Presentation"],
  FontSize->16],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Presentation"],
  FontSize->16],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->0,
  SingleLetterItalics->True,
  StyleMenuListing->None,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Presentation"],
  CellMargins->{{60, 10}, {Inherited, 6}},
  LineSpacing->{1, 5}],

Cell[StyleData["DisplayFormula", "Printout"],
  CellMargins->{{18, 4}, {4, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ChemicalFormula"],
  CellMargins->{{55, 10}, {Inherited, 0}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  TextJustification->1,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  AutoSpacing->False,
  ScriptLevel->1,
  ScriptBaselineShifts->{0.6, Automatic},
  SingleLetterItalics->False,
  ZeroWidthTimes->True],

Cell[StyleData["ChemicalFormula", "Presentation"],
  CellMargins->{{60, 10}, {Inherited, 6}}],

Cell[StyleData["ChemicalFormula", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellMargins->{{55, 10}, {Inherited, 0}},
  CellHorizontalScrolling->True,
  Hyphenation->False,
  LanguageCategory->"Formula",
  FontFamily->"Courier"],

Cell[StyleData["Program", "Presentation"],
  CellMargins->{{60, 10}, {Inherited, 6}}],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{55, 85}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedEquation", "Presentation"],
  CellMargins->{{60, 10}, {Inherited, 6}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{55, 95}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedFigure", "Presentation"],
  CellMargins->{{60, 80}, {Inherited, 6}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedFigure", "Printout"],
  CellMargins->{{18, 80}, {4, 4}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{55, 95}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedTable", "Presentation"],
  CellMargins->{{60, 80}, {Inherited, 6}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedTable", "Printout"],
  CellMargins->{{18, 80}, {4, 4}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["PageNumber"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold"],

Cell[StyleData["Footer"],
  TextAlignment->Center,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell["Slide Show Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SlideShowNavigationBar"],
  Editable->False,
  CellFrame->True,
  CellMargins->{{0, 0}, {3, 3}},
  CellGroupingRules->{"SectionGrouping", 30},
  CellFrameMargins->False,
  CellFrameColor->GrayLevel[1],
  CellFrameLabelMargins->False,
  TextAlignment->Center,
  CounterIncrements->"SlideShowNavigationBar",
  StyleMenuListing->None,
  FontSize->10,
  Background->GrayLevel[0.8],
  GridBoxOptions->{RowSpacings->0,
  ColumnSpacings->0,
  ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
  ColumnAlignments->{
    Center, Center, Center, Center, Center, Center, Right, Center}}],

Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
  Deletable->False,
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {-1, 0}},
  PageBreakAbove->True],

Cell[StyleData["SlideShowNavigationBar", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideShowSection"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellMargins->{{0, 0}, {10, 0}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 4}, {6, 12}},
  CellFrameColor->RGBColor[0.4, 0, 0.239994],
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.6, 0.749996, 0.899992]],

Cell[StyleData["SlideShowSection", "SlideShow"],
  ShowCellBracket->False,
  PageBreakAbove->True],

Cell[StyleData["SlideShowSection", "Printout"],
  CellMargins->{{18, 30}, {0, 30}},
  CellFrameMargins->5,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideHyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontSize->16,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonMargins->1.5,
  ButtonNote->ButtonData}],

Cell[StyleData["SlideHyperlink", "SlideShow"],
  FontSize->16],

Cell[StyleData["SlideHyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideTOCLink"],
  CellMargins->{{24, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Helvetica",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonMargins->1.5,
  ButtonNote->ButtonData}],

Cell[StyleData["SlideTOCLink", "SlideShow"]],

Cell[StyleData["SlideTOCLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideTOC"],
  CellDingbat->"\[Bullet]",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  FontFamily->"Helvetica"],

Cell[StyleData["SlideTOC", "SlideShow"],
  FontSize->14],

Cell[StyleData["SlideTOC", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["1ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxFrame->0.5,
  BoxMargins->True},
  GridBoxOptions->{ColumnSpacings->1}],

Cell[StyleData["1ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["1ColumnBox", "SlideShow"],
  CellMargins->{{36, 36}, {3, 6}},
  Background->RGBColor[0.700008, 0.849989, 0.949996]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxFrame->0.5,
  BoxMargins->True},
  GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],

Cell[StyleData["2ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->9,
  Background->GrayLevel[0.900008]],

Cell[StyleData["2ColumnBox", "SlideShow"],
  CellMargins->{{36, 36}, {6, 6}},
  Background->RGBColor[0.700008, 0.849989, 0.949996]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.4, 0.6},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox", "SlideShow"],
  CellMargins->{{36, 36}, {6, 6}},
  Background->RGBColor[0.700008, 0.849989, 0.949996]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 784}},
WindowSize->{500, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 64, "Subtitle"],
Cell[1767, 54, 192, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[1984, 63, 42, 0, 59, "Section"],
Cell[2029, 65, 185, 4, 56, 31, 0, "StyleData", "All", "Working"],
Cell[2217, 71, 198, 4, 40, 33, 0, "StyleData", "All", "SlideShow"],
Cell[2418, 77, 154, 3, 40, 36, 0, "StyleData", "All", "Presentation"],
Cell[2575, 82, 153, 4, 38, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2765, 91, 35, 0, 39, "Section"],
Cell[2803, 93, 101, 3, 70, "Text"],
Cell[2907, 98, 426, 11, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3370, 114, 38, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3433, 118, 1289, 30, 70, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4725, 150, 151, 3, 70, 40, 0, "StyleData", "Title", "Presentation"],
Cell[4879, 155, 110, 3, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5026, 163, 1175, 26, 70, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[6204, 191, 79, 1, 70, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[6286, 194, 91, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6414, 201, 1280, 29, 70, 28, 0, "StyleData", "Section 1", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[7697, 232, 103, 2, 70, 44, 0, "StyleData", "Section 1", "Presentation"],
Cell[7803, 236, 115, 3, 70, 40, 0, "StyleData", "Section 1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7955, 244, 1266, 29, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[9224, 275, 78, 1, 70, 42, 0, "StyleData", "Section", "Presentation"],
Cell[9305, 278, 113, 3, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9455, 286, 1179, 27, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[10637, 315, 81, 1, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[10721, 318, 93, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10851, 325, 1144, 26, 70, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[11998, 353, 84, 1, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[12085, 356, 96, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12230, 364, 39, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[12294, 368, 1016, 23, 70, 23, 0, "StyleData", "Text", "All"],
Cell[13313, 393, 162, 5, 70, 39, 0, "StyleData", "Text", "Presentation"],
Cell[13478, 400, 108, 3, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13623, 408, 209, 7, 70, 29, 0, "StyleData", "Commentary", "All"],
Cell[13835, 417, 145, 4, 70, 45, 0, "StyleData", "Commentary", \
"Presentation"],
Cell[13983, 423, 138, 4, 70, 41, 0, "StyleData", "Commentary", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14170, 433, 42, 0, 39, "Section"],
Cell[14215, 435, 248, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[14488, 444, 723, 20, 70, 24, 0, "StyleData", "Input", "All"],
Cell[15214, 466, 111, 2, 70, 40, 0, "StyleData", "Input", "Presentation"],
Cell[15328, 470, 168, 4, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[15511, 477, 491, 14, 70, 30, 0, "StyleData", "InlineInput", "All",
  CounterIncrements->"Input"],

Cell[CellGroupData[{
Cell[16027, 495, 630, 17, 70, 25, 0, "StyleData", "Output", "All"],
Cell[16660, 514, 84, 1, 70, 41, 0, "StyleData", "Output", "Presentation"],
Cell[16747, 517, 96, 2, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16880, 524, 713, 20, 70, 28, 0, "StyleData", "InputOnly", "All"],
Cell[17596, 546, 88, 1, 70, 44, 0, "StyleData", "InputOnly", "Presentation"],
Cell[17687, 549, 145, 3, 70, 40, 0, "StyleData", "InputOnly", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17869, 557, 690, 20, 70, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[18562, 579, 123, 2, 70, 42, 0, "StyleData", "Message", "Presentation"],
Cell[18688, 583, 95, 2, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18820, 590, 596, 16, 70, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[19419, 608, 83, 1, 70, 40, 0, "StyleData", "Print", "Presentation"],
Cell[19505, 611, 94, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19636, 618, 450, 13, 70, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[20089, 633, 123, 2, 70, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[20215, 637, 112, 2, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20364, 644, 157, 5, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[20524, 651, 102, 1, 70, 44, 0, "StyleData", "CellLabel", \
"Presentation"],
Cell[20629, 654, 112, 2, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20790, 662, 32, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[20847, 666, 329, 9, 70, 25, 0, "StyleData", "Author", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[21179, 677, 78, 1, 70, 41, 0, "StyleData", "Author", "Presentation"],
Cell[21260, 680, 73, 1, 70, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21370, 686, 169, 6, 70, 27, 0, "StyleData", "Abstract", "All"],
Cell[21542, 694, 106, 2, 70, 43, 0, "StyleData", "Abstract", "Presentation"],
Cell[21651, 698, 78, 2, 70, 39, 0, "StyleData", "Abstract", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21766, 705, 149, 5, 70, 26, 0, "StyleData", "Caption", "All"],
Cell[21918, 712, 93, 2, 70, 42, 0, "StyleData", "Caption", "Presentation"],
Cell[22014, 716, 111, 3, 70, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22162, 724, 154, 5, 70, 28, 0, "StyleData", "Reference", "All"],
Cell[22319, 731, 150, 4, 70, 44, 0, "StyleData", "Reference", \
"Presentation"],
Cell[22472, 737, 89, 2, 70, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22598, 744, 340, 9, 70, 31, 0, "StyleData", "PictureGroup", "All",
  StyleMenuListing->None],
Cell[22941, 755, 127, 2, 70, 47, 0, "StyleData", "PictureGroup", \
"Presentation"],
Cell[23071, 759, 116, 2, 70, 43, 0, "StyleData", "PictureGroup", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23236, 767, 35, 0, 39, "Section"],
Cell[23274, 769, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[23483, 777, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23788, 787, 60, 1, 70, 44, 0, "StyleData", "Hyperlink", "Presentation"],
Cell[23851, 790, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[23989, 796, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[24118, 803, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24437, 813, 63, 1, 70, 47, 0, "StyleData", "MainBookLink", \
"Presentation"],
Cell[24503, 816, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24666, 824, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[25006, 835, 61, 1, 70, 45, 0, "StyleData", "AddOnsLink", \
"Presentation"],
Cell[25070, 838, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25231, 846, 341, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[25575, 857, 63, 1, 70, 47, 0, "StyleData", "RefGuideLink", \
"Presentation"],
Cell[25641, 860, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25804, 868, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[26135, 878, 69, 1, 70, 53, 0, "StyleData", "GettingStartedLink", \
"Presentation"],
Cell[26207, 881, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26376, 889, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[26711, 899, 71, 1, 70, 55, 0, "StyleData", "OtherInformationLink", \
"Presentation"],
Cell[26785, 902, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26968, 911, 33, 0, 39, "Section"],
Cell[27004, 913, 121, 3, 70, "Text"],
Cell[27128, 918, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27357, 925, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27655, 934, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28058, 945, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28448, 956, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[28886, 970, 43, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[28954, 974, 445, 10, 70, 33, 0, "StyleData", "DisplayFormula", "All",
  StyleMenuListing->None],
Cell[29402, 986, 115, 2, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[29520, 990, 79, 1, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29636, 996, 462, 12, 70, 34, 0, "StyleData", "ChemicalFormula", "All"],
Cell[30101, 1010, 93, 1, 70, 50, 0, "StyleData", "ChemicalFormula", \
"Presentation"],
Cell[30197, 1013, 119, 3, 70, 46, 0, "StyleData", "ChemicalFormula", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30353, 1021, 180, 5, 70, 26, 0, "StyleData", "Program", "All"],
Cell[30536, 1028, 85, 1, 70, 42, 0, "StyleData", "Program", "Presentation"],
Cell[30624, 1031, 112, 3, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30785, 1040, 49, 0, 39, "Section"],
Cell[30837, 1042, 225, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[31087, 1050, 473, 10, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[31563, 1062, 117, 2, 70, 51, 0, "StyleData", "NumberedEquation", \
"Presentation"],
Cell[31683, 1066, 96, 2, 70, 47, 0, "StyleData", "NumberedEquation", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31816, 1073, 329, 7, 70, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[32148, 1082, 115, 2, 70, 49, 0, "StyleData", "NumberedFigure", \
"Presentation"],
Cell[32266, 1086, 95, 2, 70, 45, 0, "StyleData", "NumberedFigure", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32398, 1093, 350, 8, 70, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[32751, 1103, 114, 2, 70, 48, 0, "StyleData", "NumberedTable", \
"Presentation"],
Cell[32868, 1107, 94, 2, 70, 44, 0, "StyleData", "NumberedTable", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33011, 1115, 49, 0, 39, "Section"],
Cell[33063, 1117, 93, 3, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[33159, 1122, 119, 4, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[33281, 1128, 118, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[33436, 1137, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[33497, 1141, 588, 17, 35, 41, 0, "StyleData", "SlideShowNavigationBar", \
"All",
  CounterIncrements->"SlideShowNavigationBar",
  StyleMenuListing->None],
Cell[34088, 1160, 158, 4, 28, 54, 0, "StyleData", "SlideShowNavigationBar", \
"SlideShow"],
Cell[34249, 1166, 126, 3, 37, 53, 0, "StyleData", "SlideShowNavigationBar", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34412, 1174, 1390, 32, 66, 35, 0, "StyleData", "SlideShowSection", "All",
  
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[35805, 1208, 98, 2, 66, 48, 0, "StyleData", "SlideShowSection", \
"SlideShow"],
Cell[35906, 1212, 122, 3, 73, 47, 0, "StyleData", "SlideShowSection", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36065, 1220, 274, 8, 44, 33, 0, "StyleData", "SlideHyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36342, 1230, 62, 1, 44, 46, 0, "StyleData", "SlideHyperlink", \
"SlideShow"],
Cell[36407, 1233, 128, 3, 37, 45, 0, "StyleData", "SlideHyperlink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36572, 1241, 341, 9, 40, 31, 0, "StyleData", "SlideTOCLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36916, 1252, 44, 0, 40, 44, 0, "StyleData", "SlideTOCLink", \
"SlideShow"],
Cell[36963, 1254, 110, 2, 40, 43, 0, "StyleData", "SlideTOCLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37110, 1261, 166, 4, 40, 27, 0, "StyleData", "SlideTOC", "All",
  StyleMenuListing->None],
Cell[37279, 1267, 56, 1, 41, 40, 0, "StyleData", "SlideTOC", "SlideShow"],
Cell[37338, 1270, 82, 2, 38, 39, 0, "StyleData", "SlideTOC", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37457, 1277, 271, 8, 56, 29, 0, "StyleData", "1ColumnBox", "All",
  StyleMenuListing->None],
Cell[37731, 1287, 125, 3, 53, 41, 0, "StyleData", "1ColumnBox", "Printout"],
Cell[37859, 1292, 131, 2, 57, 42, 0, "StyleData", "1ColumnBox", "SlideShow"]
}, Closed]],

Cell[CellGroupData[{
Cell[38027, 1299, 280, 8, 56, 29, 0, "StyleData", "2ColumnBox", "All",
  StyleMenuListing->None],
Cell[38310, 1309, 124, 3, 53, 41, 0, "StyleData", "2ColumnBox", "Printout"],
Cell[38437, 1314, 131, 2, 60, 42, 0, "StyleData", "2ColumnBox", "SlideShow"]
}, Closed]],

Cell[CellGroupData[{
Cell[38605, 1321, 404, 14, 57, 32, 0, "StyleData", "DefinitionBox", "All",
  StyleMenuListing->None],
Cell[39012, 1337, 121, 3, 54, 44, 0, "StyleData", "DefinitionBox", \
"Printout"],
Cell[39136, 1342, 134, 2, 61, 45, 0, "StyleData", "DefinitionBox", \
"SlideShow"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

