(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43342,       1521]*)
(*NotebookOutlinePosition[     43977,       1543]*)
(*  CellTagsIndexPosition[     43933,       1539]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9,
  Background->RGBColor[0.899992, 0.859495, 0.809995]],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ScriptMinSize->12,
  FontSize->16],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Margins"->{1, 1},
  "Widths"->{0, 5}},
  ScriptMinSize->8,
  FontSize->11],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->7,
  FontSize->10,
  Background->GrayLevel[1],
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {"Printed from the Mathematica", " Teacher's Edition"}], 
          "Header"]}, {Cell[ 
          TextData[ {"Printed from the Mathematica", " Teacher's Edition"}], 
          "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageFooters->{{None, Cell[ 
          
          TextData[ {
            "\[Copyright]2002 Wolfram Research, Inc. All rights reserved."}], 
          "Footer"], None}, {None, Cell[ 
          
          TextData[ {
            "\[Copyright]2002 Wolfram Research, Inc. All rights reserved."}], 
          "Footer"], None}},
  PageHeaderLines->{True, True},
  PageFooterLines->{True, True},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 11},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica Black",
  FontSize->34,
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{0, 0}, {0, 0}},
  LineSpacing->{1, 0},
  FontSize->44],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->20],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  FontSize->24,
  FontTracking->"Plain",
  Background->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 3},
  ParagraphIndent->-96,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.283192, 0.453773, 0.479988]],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{0, 0}, {0, 0}},
  LineSpacing->{1, 6},
  ParagraphIndent->-157,
  FontSize->30],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-78,
  FontSize->14],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-85,
  FontSize->16,
  Background->GrayLevel[0.6]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {30, 10}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{8, 10}, {40, 20}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{8, 10}, {12, 8}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{9, 10}, {50, 10}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{6, 0}, {0, 1}},
  CellDingbat->None,
  CellMargins->{{12, Inherited}, {4, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->6,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.321309, 0.487999, 0.509987]],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{10, 10}, {8, 32}},
  LineSpacing->{1, 2},
  FontSize->24,
  FontTracking->"Condensed"],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{8, Inherited}, {2, 12}},
  FontSize->12],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{9, 0}, {2, 50}},
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellMargins->{{12, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{11, 10}, {8, 32}},
  LineSpacing->{1, 0},
  FontSize->22],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{8, Inherited}, {2, 12}},
  FontSize->12],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {4, 40}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->None,
  CellMargins->{{12, Inherited}, {8, 12}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 9},
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{29, 10}, {8, 26}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{22, Inherited}, {2, 12}},
  FontSize->10],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{21, 0}, {4, 20}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {5, 5}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  CounterIncrements->"Text",
  FontFamily->"Helvetica",
  FontSize->11],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{13, 10}, {8, 8}},
  LineSpacing->{1, 5},
  ParagraphSpacing->{0, 12}],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{8, 10}, {4, 4}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 4}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  ParagraphSpacing->{0, 6}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {5, 5}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 6},
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{13, 10}, {8, 8}},
  LineSpacing->{1, 5},
  FontSize->12],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{8, 10}, {2, 2}},
  LineSpacing->{1, 2},
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{52, 10}, {8, 8}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontFamily->"Courier",
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.696666, 0.600015]],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{62, Inherited}, {10, 10}},
  LineSpacing->{1, 0}],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{40, 10}, {4, 4}}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{44, 0}, {6, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  Background->GrayLevel[0.8]]
}, Closed]],

Cell[StyleData["InlineInput"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontFamily->"Courier",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{52, 10}, {8, 8}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output",
  FontFamily->"Courier",
  FontWeight->"Bold",
  Background->RGBColor[0.859998, 0.793484, 0.722408]],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{62, Inherited}, {12, 5}},
  LineSpacing->{1, 0}],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{40, Inherited}, {4, 1}}],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{44, 0}, {6, 2}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{62, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{74, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{50, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{54, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{62, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{74, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{50, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{62, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{74, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Graphics", "Condensed"],
  CellMargins->{{52, Inherited}, {Inherited, Inherited}},
  ImageSize->{175, 175}],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{54, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->11,
  FontWeight->"Bold",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->12],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->8],

Cell[StyleData["CellLabel", "Printout"],
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unique Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {2, 10}},
  LineSpacing->{1, 5},
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Plain"],

Cell[StyleData["Author", "Presentation"],
  CellMargins->{{12, 10}, {2, 12}},
  LineSpacing->{1, 5},
  ParagraphSpacing->{0, 12},
  FontSize->20],

Cell[StyleData["Author", "Condensed"],
  CellMargins->{{8, 10}, {1, 4}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 4},
  FontSize->12],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{9, 0}, {4, 12}},
  ParagraphSpacing->{0, 6},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Copyright"],
  ShowCellBracket->False,
  CellMargins->{{10, 10}, {40, 2}},
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Copyright", "Presentation"],
  CellMargins->{{12, 10}, {50, 2}},
  LineSpacing->{1, 5},
  FontSize->12],

Cell[StyleData["Copyright", "Condensed"],
  CellMargins->{{8, 10}, {12, 1}},
  LineSpacing->{1, 2},
  FontSize->9],

Cell[StyleData["Copyright", "Printout"],
  CellMargins->{{9, 0}, {72, 4}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Example"],
  CellMargins->{{12, 10}, {5, 12}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 12},
  CounterIncrements->"Example",
  FontFamily->"Times",
  FontWeight->"Bold"],

Cell[StyleData["Example", "Presentation"],
  CellMargins->{{18, 10}, {8, 20}},
  LineSpacing->{1, 5},
  ParagraphSpacing->{0, 12}],

Cell[StyleData["Example", "Condensed"],
  CellMargins->{{8, 10}, {4, 8}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 4}],

Cell[StyleData["Example", "Printout"],
  CellMargins->{{9, 0}, {4, 10}},
  ParagraphSpacing->{0, 6}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Definition"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{52, 10}, {8, 8}},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  Hyphenation->True,
  ShowStringCharacters->True,
  CounterIncrements->"Definition",
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0.700008, 0.700008]],

Cell[StyleData["Definition", "Presentation"],
  CellMargins->{{62, Inherited}, {5, 12}},
  LineSpacing->{1, 0}],

Cell[StyleData["Definition", "Condensed"],
  CellMargins->{{40, 10}, {1, 4}}],

Cell[StyleData["Definition", "Printout"],
  CellMargins->{{44, 0}, {2, 6}},
  Background->GrayLevel[0.6]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{52, 10}, {8, 8}},
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  Hyphenation->True,
  ShowStringCharacters->True,
  CounterIncrements->"Theorem",
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["Theorem", "Presentation"],
  CellMargins->{{62, Inherited}, {5, 12}},
  LineSpacing->{1, 0}],

Cell[StyleData["Theorem", "Condensed"],
  CellMargins->{{40, 10}, {1, 4}}],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{44, 0}, {2, 6}},
  Background->GrayLevel[0.4]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExerciseMain"],
  CellFrame->{{6, 0}, {0, 1}},
  CellMargins->{{12, Inherited}, {4, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
  LineSpacing->{1, 7},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["ExerciseMain", "Presentation"],
  CellMargins->{{18, 10}, {8, 32}},
  LineSpacing->{1, 2},
  FontSize->24,
  FontTracking->"Condensed"],

Cell[StyleData["ExerciseMain", "Condensed"],
  CellMargins->{{8, Inherited}, {2, 12}},
  FontSize->12],

Cell[StyleData["ExerciseMain", "Printout"],
  CellMargins->{{9, 0}, {2, 50}},
  CellFrameColor->GrayLevel[0.500008],
  FontSize->14,
  FontTracking->"Plain",
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Exercise"],
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{23, Inherited}, {4, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  Hyphenation->True,
  LineSpacing->{1, 7},
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->13,
  FontWeight->"Bold",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["Exercise", "Presentation"],
  CellMargins->{{33, 10}, {8, 26}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["Exercise", "Condensed"],
  CellMargins->{{17, Inherited}, {2, 12}},
  FontSize->10],

Cell[StyleData["Exercise", "Printout"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellDingbat->None,
  CellMargins->{{9, 0}, {6, 20}},
  FontSize->11,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExerciseText"],
  CellMargins->{{62, 10}, {5, 5}},
  Hyphenation->True,
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"ExcersiceText",
  FontFamily->"Times"],

Cell[StyleData["ExerciseText", "Presentation"],
  CellMargins->{{74, 10}, {8, 8}},
  LineSpacing->{1, 5},
  ParagraphSpacing->{0, 12}],

Cell[StyleData["ExerciseText", "Condensed"],
  CellMargins->{{52, 10}, {2, 2}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 4}],

Cell[StyleData["ExerciseText", "Printout"],
  CellMargins->{{54, 0}, {4, 4}},
  ParagraphSpacing->{0, 6}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{62, 10}, {2, 10}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Presentation"],
  CellMargins->{{74, 10}, {2, 10}},
  FontSize->10],

Cell[StyleData["DisplayFormula", "Condensed"],
  CellMargins->{{52, 10}, {2, 10}},
  FontSize->10],

Cell[StyleData["DisplayFormula", "Printout"],
  CellMargins->{{54, 10}, {2, 10}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ChemicalFormula"],
  CellMargins->{{62, 10}, {2, 10}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  AutoSpacing->False,
  ScriptLevel->1,
  ScriptBaselineShifts->{0.6, Automatic},
  SingleLetterItalics->False,
  ZeroWidthTimes->True],

Cell[StyleData["ChemicalFormula", "Presentation"],
  CellMargins->{{74, 10}, {2, 10}},
  FontSize->10],

Cell[StyleData["ChemicalFormula", "Condensed"],
  CellMargins->{{52, 10}, {2, 10}},
  FontSize->10],

Cell[StyleData["ChemicalFormula", "Printout"],
  CellMargins->{{54, 10}, {2, 10}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellMargins->{{12, 10}, {Inherited, 6}},
  Hyphenation->False,
  LanguageCategory->"Formula",
  FontFamily->"Courier"],

Cell[StyleData["Program", "Presentation"],
  CellMargins->{{13, 30}, {Inherited, 4}},
  FontSize->9.5],

Cell[StyleData["Program", "Condensed"],
  CellMargins->{{8, 10}, {Inherited, 4}},
  FontSize->9.5],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{9, 0}, {Inherited, 4}},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{62, 10}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Presentation"],
  CellMargins->{{74, 10}, {Inherited, Inherited}}],

Cell[StyleData["NumberedEquation", "Condensed"],
  CellMargins->{{52, 10}, {Inherited, Inherited}}],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{54, 0}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{62, 145}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}]], None}},
  CounterIncrements->"NumberedFigure",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedFigure", "Presentation"]],

Cell[StyleData["NumberedFigure", "Condensed"]],

Cell[StyleData["NumberedFigure", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{62, 145}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}]], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedTable", "Presentation"]],

Cell[StyleData["NumberedTable", "Condensed"]],

Cell[StyleData["NumberedTable", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->6],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlinks", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(NotebookLocate[ {
      URL[ 
        StringJoin[ "http://documents.wolfram.com/v4_1/MainBook/", 
          Part[ #2, 1], ".html"]], None}]&),
  ButtonEvaluator->"Local",
  Active->True,
  ButtonSource->ButtonData,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MainBookLinkMR"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(NotebookLocate[ {
      URL[ 
        StringJoin[ "http://documents.wolfram.com/v4_1/MainBook/", 
          Part[ #2, 1], ".html"]], None}]&),
  ButtonEvaluator->"Local",
  Active->True,
  ButtonSource->ButtonData,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLinkMR", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLinkMR", "EnhancedPrintout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLinkMR", "EnhancedPrintoutNonGray"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TeachersBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MathematicaBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["TeachersBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeachersBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeachersBookLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TeachersBookLinkMR"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MathematicaBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["TeachersBookLinkMR", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeachersBookLinkMR", "EnhancedPrintout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeachersBookLinkMR", "EnhancedPrintoutNonGray"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TeacherLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Teacher", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["TeacherLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeacherLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeacherLink", "EnhancedPrintoutNonGray"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Teacher", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintoutNonGray"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TeacherLinkText"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Teacher", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["TeacherLinkText", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeacherLinkText", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TeacherLinkText", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintoutNonGray"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLinkMR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLinkMR", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintoutNonGray"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1106}, {0, 848}},
WindowSize->{650, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 65, "Subtitle"],
Cell[1816, 55, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2034, 63, 42, 0, 56, "Section"],
Cell[2079, 65, 131, 3, 52, 31, 0, "StyleData", "All", "Working"],
Cell[2213, 70, 99, 3, 40, 36, 0, "StyleData", "All", "Presentation"],
Cell[2315, 75, 158, 5, 35, 33, 0, "StyleData", "All", "Condensed"],
Cell[2476, 82, 168, 5, 34, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2681, 92, 35, 0, 36, "Section"],
Cell[2719, 94, 99, 2, 32, "Text"],
Cell[2821, 98, 945, 24, 38, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3803, 127, 38, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[3866, 131, 1037, 25, 77, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[4906, 158, 112, 3, 70, 40, 0, "StyleData", "Title", "Presentation"],
Cell[5021, 163, 86, 2, 70, 37, 0, "StyleData", "Title", "Condensed"],
Cell[5110, 167, 138, 4, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5285, 176, 1092, 27, 54, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[6380, 205, 140, 4, 70, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[6523, 211, 113, 3, 70, 40, 0, "StyleData", "Subtitle", "Condensed"],
Cell[6639, 216, 142, 4, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6818, 225, 969, 23, 66, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[7790, 250, 121, 3, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[7914, 255, 94, 2, 70, 43, 0, "StyleData", "Subsubtitle", "Condensed"],
Cell[8011, 259, 94, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8142, 266, 1108, 27, 47, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[9253, 295, 146, 4, 70, 42, 0, "StyleData", "Section", "Presentation"],
Cell[9402, 301, 97, 2, 70, 39, 0, "StyleData", "Section", "Condensed"],
Cell[9502, 305, 140, 4, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9679, 314, 967, 23, 44, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[10649, 339, 120, 3, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[10772, 344, 100, 2, 70, 42, 0, "StyleData", "Subsection", "Condensed"],
Cell[10875, 348, 91, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11003, 355, 971, 24, 42, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[11977, 381, 123, 3, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[12103, 386, 104, 2, 70, 45, 0, "StyleData", "Subsubsection", \
"Condensed"],
Cell[12210, 390, 95, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12354, 398, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[12418, 402, 858, 21, 37, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[13279, 425, 126, 3, 70, 39, 0, "StyleData", "Text", "Presentation"],
Cell[13408, 430, 121, 3, 70, 36, 0, "StyleData", "Text", "Condensed"],
Cell[13532, 435, 96, 2, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13665, 442, 866, 21, 35, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[14534, 465, 118, 3, 70, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[14655, 470, 113, 3, 70, 41, 0, "StyleData", "SmallText", "Condensed"],
Cell[14771, 475, 88, 2, 70, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14908, 483, 42, 0, 36, "Section"],
Cell[14953, 485, 246, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[15224, 493, 691, 19, 61, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[15918, 514, 107, 2, 70, 40, 0, "StyleData", "Input", "Presentation"],
Cell[16028, 518, 72, 1, 70, 37, 0, "StyleData", "Input", "Condensed"],
Cell[16103, 521, 145, 3, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[16263, 527, 467, 14, 37, 30, 0, "StyleData", "InlineInput", "All",
  CounterIncrements->"Input"],

Cell[CellGroupData[{
Cell[16755, 545, 660, 18, 61, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[17418, 565, 107, 2, 70, 41, 0, "StyleData", "Output", "Presentation"],
Cell[17528, 569, 80, 1, 70, 38, 0, "StyleData", "Output", "Condensed"],
Cell[17611, 572, 106, 2, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17754, 579, 482, 13, 36, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[18239, 594, 123, 2, 70, 42, 0, "StyleData", "Message", "Presentation"],
Cell[18365, 598, 97, 1, 70, 39, 0, "StyleData", "Message", "Condensed"],
Cell[18465, 601, 123, 2, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18625, 608, 479, 13, 36, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[19107, 623, 121, 2, 70, 40, 0, "StyleData", "Print", "Presentation"],
Cell[19231, 627, 95, 1, 70, 37, 0, "StyleData", "Print", "Condensed"],
Cell[19329, 630, 94, 1, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19460, 636, 389, 11, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[19852, 649, 101, 1, 70, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[19956, 652, 123, 2, 70, 40, 0, "StyleData", "Graphics", "Condensed"],
Cell[20082, 656, 122, 2, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20241, 663, 171, 5, 35, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[20415, 670, 60, 1, 70, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[20478, 673, 56, 1, 70, 41, 0, "StyleData", "CellLabel", "Condensed"],
Cell[20537, 676, 82, 2, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20668, 684, 32, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[20725, 688, 174, 6, 40, 25, 0, "StyleData", "Author", "All"],
Cell[20902, 696, 145, 4, 70, 41, 0, "StyleData", "Author", "Presentation"],
Cell[21050, 702, 139, 4, 70, 38, 0, "StyleData", "Author", "Condensed"],
Cell[21192, 708, 115, 3, 70, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21344, 716, 132, 4, 70, 28, 0, "StyleData", "Copyright", "All"],
Cell[21479, 722, 119, 3, 70, 44, 0, "StyleData", "Copyright", \
"Presentation"],
Cell[21601, 727, 114, 3, 70, 41, 0, "StyleData", "Copyright", "Condensed"],
Cell[21718, 732, 89, 2, 70, 40, 0, "StyleData", "Copyright", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21844, 739, 191, 6, 39, 26, 0, "StyleData", "Example", "All",
  CounterIncrements->"Example"],
Cell[22038, 747, 130, 3, 70, 42, 0, "StyleData", "Example", "Presentation"],
Cell[22171, 752, 124, 3, 70, 39, 0, "StyleData", "Example", "Condensed"],
Cell[22298, 757, 100, 2, 70, 38, 0, "StyleData", "Example", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22435, 764, 426, 12, 58, 29, 0, "StyleData", "Definition", "All",
  CounterIncrements->"Definition"],
Cell[22864, 778, 111, 2, 70, 45, 0, "StyleData", "Definition", \
"Presentation"],
Cell[22978, 782, 77, 1, 70, 42, 0, "StyleData", "Definition", "Condensed"],
Cell[23058, 785, 105, 2, 70, 41, 0, "StyleData", "Definition", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23200, 792, 424, 12, 58, 26, 0, "StyleData", "Theorem", "All",
  CounterIncrements->"Theorem"],
Cell[23627, 806, 108, 2, 70, 42, 0, "StyleData", "Theorem", "Presentation"],
Cell[23738, 810, 74, 1, 70, 39, 0, "StyleData", "Theorem", "Condensed"],
Cell[23815, 813, 102, 2, 70, 38, 0, "StyleData", "Theorem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23954, 820, 454, 12, 49, 31, 0, "StyleData", "ExerciseMain", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[24411, 834, 151, 4, 70, 47, 0, "StyleData", "ExerciseMain", \
"Presentation"],
Cell[24565, 840, 102, 2, 70, 44, 0, "StyleData", "ExerciseMain", \
"Condensed"],
Cell[24670, 844, 184, 5, 70, 43, 0, "StyleData", "ExerciseMain", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24891, 854, 376, 11, 37, 27, 0, "StyleData", "Exercise", "All",
  CounterIncrements->"Subsubsection"],
Cell[25270, 867, 118, 3, 70, 43, 0, "StyleData", "Exercise", "Presentation"],
Cell[25391, 872, 99, 2, 70, 40, 0, "StyleData", "Exercise", "Condensed"],
Cell[25493, 876, 170, 5, 70, 39, 0, "StyleData", "Exercise", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25700, 886, 199, 6, 37, 31, 0, "StyleData", "ExerciseText", "All",
  CounterIncrements->"ExcersiceText"],
Cell[25902, 894, 134, 3, 70, 47, 0, "StyleData", "ExerciseText", \
"Presentation"],
Cell[26039, 899, 130, 3, 70, 44, 0, "StyleData", "ExerciseText", \
"Condensed"],
Cell[26172, 904, 105, 2, 70, 43, 0, "StyleData", "ExerciseText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26326, 912, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[26394, 916, 348, 8, 40, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[26745, 926, 101, 2, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[26849, 930, 98, 2, 70, 46, 0, "StyleData", "DisplayFormula", \
"Condensed"],
Cell[26950, 934, 97, 2, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27084, 941, 349, 9, 34, 34, 0, "StyleData", "ChemicalFormula", "All"],
Cell[27436, 952, 102, 2, 70, 50, 0, "StyleData", "ChemicalFormula", \
"Presentation"],
Cell[27541, 956, 99, 2, 70, 47, 0, "StyleData", "ChemicalFormula", \
"Condensed"],
Cell[27643, 960, 98, 2, 70, 46, 0, "StyleData", "ChemicalFormula", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27778, 967, 147, 4, 36, 26, 0, "StyleData", "Program", "All"],
Cell[27928, 973, 102, 2, 70, 42, 0, "StyleData", "Program", "Presentation"],
Cell[28033, 977, 98, 2, 70, 39, 0, "StyleData", "Program", "Condensed"],
Cell[28134, 981, 96, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28279, 989, 49, 0, 36, "Section"],
Cell[28331, 991, 225, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[28581, 999, 401, 8, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[28985, 1009, 102, 1, 70, 51, 0, "StyleData", "NumberedEquation", \
"Presentation"],
Cell[29090, 1012, 99, 1, 70, 48, 0, "StyleData", "NumberedEquation", \
"Condensed"],
Cell[29192, 1015, 97, 1, 70, 47, 0, "StyleData", "NumberedEquation", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29326, 1021, 336, 7, 70, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[29665, 1030, 49, 0, 70, 49, 0, "StyleData", "NumberedFigure", \
"Presentation"],
Cell[29717, 1032, 46, 0, 70, 46, 0, "StyleData", "NumberedFigure", \
"Condensed"],
Cell[29766, 1034, 45, 0, 70, 45, 0, "StyleData", "NumberedFigure", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29848, 1039, 306, 7, 70, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[30157, 1048, 48, 0, 70, 48, 0, "StyleData", "NumberedTable", \
"Presentation"],
Cell[30208, 1050, 45, 0, 70, 45, 0, "StyleData", "NumberedTable", \
"Condensed"],
Cell[30256, 1052, 44, 0, 70, 44, 0, "StyleData", "NumberedTable", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30349, 1058, 49, 0, 36, "Section"],
Cell[30401, 1060, 149, 5, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[30553, 1067, 126, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[30682, 1073, 152, 5, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[30871, 1083, 29, 0, 36, "Section"],
Cell[30903, 1085, 340, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[31268, 1095, 302, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31573, 1105, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[31699, 1110, 157, 4, 70, 48, 0, "StyleData", "Hyperlink", \
"EnhancedPrintout"],
Cell[31859, 1116, 164, 4, 70, 55, 0, "StyleData", "Hyperlink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[32060, 1125, 442, 12, 36, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[32505, 1139, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"],
Cell[32634, 1144, 160, 4, 70, 51, 0, "StyleData", "MainBookLink", \
"EnhancedPrintout"],
Cell[32797, 1150, 167, 4, 70, 58, 0, "StyleData", "MainBookLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[33001, 1159, 469, 13, 36, 33, 0, "StyleData", "MainBookLinkMR", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[33473, 1174, 128, 3, 70, 45, 0, "StyleData", "MainBookLinkMR", \
"Printout"],
Cell[33604, 1179, 136, 3, 70, 53, 0, "StyleData", "MainBookLinkMR", \
"EnhancedPrintout"],
Cell[33743, 1184, 143, 3, 70, 60, 0, "StyleData", "MainBookLinkMR", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[33923, 1192, 327, 8, 36, 35, 0, "StyleData", "TeachersBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[34253, 1202, 130, 3, 70, 47, 0, "StyleData", "TeachersBookLink", \
"Printout"],
Cell[34386, 1207, 164, 4, 70, 55, 0, "StyleData", "TeachersBookLink", \
"EnhancedPrintout"],
Cell[34553, 1213, 171, 4, 70, 62, 0, "StyleData", "TeachersBookLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[34761, 1222, 354, 9, 36, 37, 0, "StyleData", "TeachersBookLinkMR", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35118, 1233, 132, 3, 70, 49, 0, "StyleData", "TeachersBookLinkMR", \
"Printout"],
Cell[35253, 1238, 140, 3, 70, 57, 0, "StyleData", "TeachersBookLinkMR", \
"EnhancedPrintout"],
Cell[35396, 1243, 147, 3, 70, 64, 0, "StyleData", "TeachersBookLinkMR", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[35580, 1251, 314, 8, 36, 30, 0, "StyleData", "TeacherLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35897, 1261, 125, 3, 70, 42, 0, "StyleData", "TeacherLink", "Printout"],
Cell[36025, 1266, 161, 4, 70, 50, 0, "StyleData", "TeacherLink", \
"EnhancedPrintout"],
Cell[36189, 1272, 168, 4, 70, 57, 0, "StyleData", "TeacherLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[36394, 1281, 338, 9, 36, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36735, 1292, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"],
Cell[36862, 1297, 160, 4, 70, 49, 0, "StyleData", "AddOnsLink", \
"EnhancedPrintout"],
Cell[37025, 1303, 167, 4, 70, 56, 0, "StyleData", "AddOnsLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[37229, 1312, 341, 9, 36, 34, 0, "StyleData", "TeacherLinkText", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[37573, 1323, 129, 3, 70, 46, 0, "StyleData", "TeacherLinkText", \
"Printout"],
Cell[37705, 1328, 163, 4, 70, 54, 0, "StyleData", "TeacherLinkText", \
"EnhancedPrintout"],
Cell[37871, 1334, 170, 4, 70, 61, 0, "StyleData", "TeacherLinkText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[38078, 1343, 341, 9, 36, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38422, 1354, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"],
Cell[38551, 1359, 162, 4, 70, 51, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintout"],
Cell[38716, 1365, 169, 4, 70, 58, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[38922, 1374, 328, 8, 36, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39253, 1384, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[39388, 1389, 166, 4, 70, 57, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintout"],
Cell[39557, 1395, 173, 4, 70, 64, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[39767, 1404, 332, 8, 36, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40102, 1414, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"],
Cell[40239, 1419, 168, 4, 70, 59, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintout"],
Cell[40410, 1425, 175, 4, 70, 66, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[40622, 1434, 322, 8, 36, 41, 0, "StyleData", "OtherInformationLinkMR", \
"All",
  StyleMenuListing->None],
Cell[40947, 1444, 136, 3, 70, 53, 0, "StyleData", "OtherInformationLinkMR", \
"Printout"],
Cell[41086, 1449, 144, 3, 70, 61, 0, "StyleData", "OtherInformationLinkMR", \
"EnhancedPrintout"],
Cell[41233, 1454, 151, 3, 70, 68, 0, "StyleData", "OtherInformationLinkMR", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41433, 1463, 33, 0, 36, "Section"],
Cell[41469, 1465, 121, 3, 46, "Text"],
Cell[41593, 1470, 226, 5, 36, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41822, 1477, 295, 7, 36, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42120, 1486, 400, 9, 36, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42523, 1497, 387, 9, 36, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42913, 1508, 401, 9, 36, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

